(function(e){e.html5={};e.html5.version="6.2.3115"})(jwplayer);
(function(e){function f(a){return function(){a("Error loading file")}}function c(a,d,c,b){return function(){try{var h=a.responseXML;if(h&&h.firstChild)return c(a)}catch(g){}(h=e.parseXML(a.responseText))&&h.firstChild?(a=e.extend({},a,{responseXML:h}),c(a)):b&&b(a.responseText?"Invalid XML":d)}}var b=window;e.serialize=function(a){return null==a?null:"true"==a.toString().toLowerCase()?!0:"false"==a.toString().toLowerCase()?!1:isNaN(Number(a))||5<a.length||0==a.length?a:Number(a)};e.filterSources=
function(a){var d,c,b=e.extensionmap;if(a){c=[];for(var h=0;h<a.length;h++){var g=a[h].type,f=a[h].file;g||(g=b.extType(e.extension(f)),a[h].type=g);if((f=e.extensionmap.types[g])&&jwplayer.vid.canPlayType(f))d||(d=g),g==d&&c.push(e.extend({},a[h]))}}return c};e.ajax=function(a,d,j){var n;0<a.indexOf("#")&&(a=a.replace(/#.*$/,""));var h;h=(h=a)&&0<=h.indexOf("://")&&h.split("/")[2]!=b.location.href.split("/")[2]?!0:!1;if(h&&e.exists(b.XDomainRequest))n=new XDomainRequest,n.onload=c(n,a,d,j),n.onerror=
f(j,a,n);else if(e.exists(b.XMLHttpRequest)){var g=n=new XMLHttpRequest,t=a;n.onreadystatechange=function(){if(4===g.readyState)switch(g.status){case 200:c(g,t,d,j)();break;case 404:j("File not found")}};n.onerror=f(j,a)}else j&&j();try{n.open("GET",a,!0),n.send(null)}catch(k){j&&j(a)}return n};e.parseXML=function(a){try{var d;if(b.DOMParser){d=(new DOMParser).parseFromString(a,"text/xml");try{if("parsererror"==d.childNodes[0].firstChild.nodeName)return}catch(c){}}else d=new ActiveXObject("Microsoft.XMLDOM"),
d.async="false",d.loadXML(a);return d}catch(f){}};e.parseDimension=function(a){if("string"==typeof a){if(""===a)return 0;if(!(-1<a.lastIndexOf("%")))return parseInt(a.replace("px",""),10)}return a};e.timeFormat=function(a){if(0<a){var d=Math.floor(a/3600),c=Math.floor((a-3600*d)/60);a=Math.floor(a%60);return(d?d+":":"")+(10>c?"0":"")+c+":"+(10>a?"0":"")+a}return"00:00"};e.seconds=function(a){a=a.replace(",",".");var c=a.split(":"),b=0;"s"==a.substr(-1)?b=Number(a.substr(0,a.length-1)):"m"==a.substr(-1)?
b=60*Number(a.substr(0,a.length-1)):"h"==a.substr(-1)?b=3600*Number(a.substr(0,a.length-1)):1<c.length?(b=Number(c[c.length-1]),b+=60*Number(c[c.length-2]),3==c.length&&(b+=3600*Number(c[c.length-3]))):b=Number(a);return b};e.bounds=function(a){if(!a)return{left:0,right:0,width:0,height:0,top:0,bottom:0};var c=a,b=0,f=0,h=isNaN(a.offsetWidth)?0:a.offsetWidth;a=isNaN(a.offsetHeight)?0:a.offsetHeight;do b+=isNaN(c.offsetLeft)?0:c.offsetLeft,f+=isNaN(c.offsetTop)?0:c.offsetTop;while(c=c.offsetParent);
return{left:b,top:f,width:h,height:a,right:b+h,bottom:f+a}};e.empty=function(a){if(a)for(;0<a.childElementCount;)a.removeChild(a.children[0])}})(jwplayer.utils);
(function(e){function f(){var a=document.createElement("style");a.type="text/css";document.getElementsByTagName("head")[0].appendChild(a);return a}function c(c){if(t)a[c].innerHTML=b(c);else{var d=a[c].sheet,h=g[c];if(d){var j=d.cssRules;e.exists(h)&&h<j.length&&j[h].selectorText==c?d.deleteRule(h):g[c]=j.length;d.insertRule(b(c),g[c])}}}function b(a){var c=a+"{\n";a=j[a];for(var b in a)c+="  "+b+": "+a[b]+";\n";return c+"}\n"}var a={},d,j={},n=0,h=e.exists,g={},t=!1,k=e.css=function(b,g,k){if(!a[b])if(t)a[b]=
f();else{if(!d||5E4<d.sheet.cssRules.length)d=f();a[b]=d}h(k)||(k=!1);j[b]||(j[b]={});for(var y in g){var u;a:{u=y;var m=g[y];if("undefined"===typeof m)u=void 0;else{var A=k?" !important":"";if(isNaN(m))u=m.match(/png|gif|jpe?g/i)&&0>m.indexOf("url")?"url("+m+")":m+A;else switch(u){case "z-index":case "opacity":u=m+A;break a;default:u=u.match(/color/i)?"#"+e.pad(m.toString(16).replace(/^0x/i,""),6)+A:0===m?0+A:Math.ceil(m)+"px"+A}}}h(j[b][y])&&!h(u)?delete j[b][y]:h(u)&&(j[b][y]=u)}0<n||c(b)};k.block=
function(){n++};k.unblock=function(){n=Math.max(n-1,0);if(0==n)for(var b in a)c(b)};e.clearCss=function(c){for(var b in j)0<=b.indexOf(c)&&delete j[b];for(var d in a)0<=d.indexOf(c)&&(a[d].innerHTML="")};e.transform=function(a,c){var b="-transform",d;c=c?c:"";"string"==typeof a?(d={},d["-webkit"+b]=c,d["-ms"+b]=c,d["-moz"+b]=c,d["-o"+b]=c,e.css(a,d)):(b="Transform",d=a.style,d["webkit"+b]=c,d["Moz"+b]=c,d["ms"+b]=c,d["O"+b]=c)};e.dragStyle=function(a,c){e.css(a,{"-webkit-user-select":c,"-moz-user-select":c,
"-ms-user-select":c,"-webkit-user-drag":c,"user-select":c,"user-drag":c})};e.transitionStyle=function(a,c){navigator.userAgent.match(/5\.\d(\.\d)? safari/i)||e.css(a,{"-webkit-transition":c,"-moz-transition":c,"-o-transition":c})};e.rotate=function(a,c){e.transform(a,"rotate("+c+"deg)")};k(".jwplayer "+" div span a img ul li video".split(" ").join(",.jwplayer ")+", .jwclick",{margin:0,padding:0,border:0,color:"#000000","font-size":"100%",font:"inherit","vertical-align":"baseline","background-color":"transparent",
"text-align":"left"});k(".jwplayer ul",{"list-style":"none"})})(jwplayer.utils);
(function(e){e.scale=function(c,b,a,d,j){var f=e.exists;f(b)||(b=1);f(a)||(a=1);f(d)||(d=0);f(j)||(j=0);e.transform(c,1==b&&1==a&&0==d&&0==j?"":"scale("+b+","+a+") translate("+d+"px,"+j+"px)")};e.stretch=function(c,b,a,d,j,n){if(b&&(c||(c=f.UNIFORM),a&&d&&j&&n)){var h=a/j,g=d/n,t="video"==b.tagName.toLowerCase(),k=!1,s;t&&e.transform(b);s="jw"+c.toLowerCase();switch(c.toLowerCase()){case f.FILL:h>g?(j*=h,n*=h):(j*=g,n*=g);case f.NONE:h=g=1;case f.EXACTFIT:k=!0;break;default:h>g?0.95<j*g/a?(k=!0,s=
"jwexactfit"):(j*=g,n*=g):0.95<n*h/d?(k=!0,s="jwexactfit"):(j*=h,n*=h),k&&(g=Math.ceil(100*d/n)/100,h=Math.ceil(100*a/j)/100)}t?k?(b.style.width=j+"px",b.style.height=n+"px",e.scale(b,h,g,(a-j)/2/h,(d-n)/2/g)):(b.style.width="",b.style.height=""):(b.className=b.className.replace(/\s*jw(none|exactfit|uniform|fill)/g,""),b.className+=" "+s)}};var f=e.stretching={NONE:"none",FILL:"fill",UNIFORM:"uniform",EXACTFIT:"exactfit"}})(jwplayer.utils);
(function(e){e.parsers={localName:function(f){return f?f.localName?f.localName:f.baseName?f.baseName:"":""},textContent:function(f){return f?f.textContent?f.textContent:f.text?f.text:"":""},getChildNode:function(f,c){return f.childNodes[c]},numChildren:function(f){return f.childNodes?f.childNodes.length:0}}})(jwplayer.html5);
(function(e){e.dfxp=function(f,c){var b,a,d=jwplayer.utils.seconds;this.load=function(d){a=d;try{b.open("GET",d,!0),b.send(null)}catch(f){c("Error loading DFXP File: "+d)}};b=new XMLHttpRequest;b.onreadystatechange=function(){if(4===b.readyState)if(200===b.status){for(var j=b.responseText,e=[{begin:0,text:""}],j=j.replace(/^\s+/,"").replace(/\s+$/,""),j=j.split("\x3c/p\x3e"),h=[],g=0;g<j.length;g++)0<=j[g].indexOf("\x3cp")&&(j[g]=j[g].substr(j[g].indexOf("\x3cp")+2).replace(/^\s+/,"").replace(/\s+$/,
""),h.push(j[g]));j=h;for(g=0;g<j.length;g++){var h=j[g],t={};try{var k=h.indexOf('begin\x3d"'),h=h.substr(k+7),k=h.indexOf('" end\x3d"');t.begin=d(h.substr(0,k));h=h.substr(k+7);k=h.indexOf('"\x3e');t.end=d(h.substr(0,k));h=h.substr(k+2);t.text=h}catch(s){}h=t;h.text&&(e.push(h),h.end&&(e.push({begin:h.end,text:""}),delete h.end))}1<e.length?f(e):c("Invalid DFXP file: "+a)}else e=b.status,0==e?c("Crossdomain loading denied: "+a):404==e?c("DFXP File not found: "+a):c("Error "+e+" loading DFXP file: "+
a)}}})(jwplayer.html5.parsers);(function(e){var f=e.html5.parsers;(f.jwparser=function(){}).parseEntry=function(c,b){for(var a=0;a<c.childNodes.length;a++){var d=c.childNodes[a];if("jwplayer"==d.prefix){var j=f.localName(d);b[j]=e.utils.serialize(f.textContent(d));"file"==j&&b.sources&&delete b.sources}b.file||(b.file=b.link)}return b}})(jwplayer);
(function(e){var f=jwplayer.utils,c=f.xmlAttribute,b=e.localName,a=e.textContent,d=e.numChildren,j=e.mediaparser=function(){};j.parseGroup=function(e,h){var g,t,k=[];for(t=0;t<d(e);t++)if(g=e.childNodes[t],"media"==g.prefix&&b(g))switch(b(g).toLowerCase()){case "content":c(g,"duration")&&(h.duration=f.seconds(c(g,"duration")));0<d(g)&&(h=j.parseGroup(g,h));c(g,"url")&&(h.sources||(h.sources=[]),h.sources.push({file:c(g,"url"),type:c(g,"type"),width:c(g,"width"),label:c(g,"height")?c(g,"height")+"p":
void 0}));break;case "title":h.title=a(g);break;case "description":h.description=a(g);break;case "guid":h.mediaid=a(g);break;case "thumbnail":h.image=c(g,"url");break;case "group":j.parseGroup(g,h);break;case "subtitle":var s={};s.file=c(g,"url");if(0<c(g,"lang").length){var l=s;g=c(g,"lang");var q={zh:"Chinese",nl:"Dutch",en:"English",fr:"French",de:"German",it:"Italian",ja:"Japanese",pt:"Portuguese",ru:"Russian",es:"Spanish"};g=q[g]?q[g]:g;l.label=g}k.push(s)}0<k.length&&(h.captions=k);return h}})(jwplayer.html5.parsers);
(function(e){function f(a){for(var d={},g=0;g<a.childNodes.length;g++){var f=a.childNodes[g],k=j(f);if(k)switch(k.toLowerCase()){case "enclosure":d.file=c.xmlAttribute(f,"url");break;case "title":d.title=b(f);break;case "guid":d.mediaid=b(f);break;case "pubdate":d.date=b(f);break;case "description":d.description=b(f);break;case "link":d.link=b(f);break;case "category":d.tags=d.tags?d.tags+b(f):b(f)}}d=e.mediaparser.parseGroup(a,d);d=e.jwparser.parseEntry(a,d);return new jwplayer.playlist.item(d)}
var c=jwplayer.utils,b=e.textContent,a=e.getChildNode,d=e.numChildren,j=e.localName;e.rssparser={};e.rssparser.parse=function(c){for(var b=[],g=0;g<d(c);g++){var e=a(c,g);if("channel"==j(e).toLowerCase())for(var k=0;k<d(e);k++){var s=a(e,k);"item"==j(s).toLowerCase()&&b.push(f(s))}}return b}})(jwplayer.html5.parsers);
(function(e){e.srt=function(f,c){function b(a){0==a?c("Crossdomain loading denied: "+j):404==a?c("SRT File not found: "+j):c("Error "+a+" loading SRT file: "+j)}function a(a){var b=[{begin:0,text:""}];a=a.replace(/^\s+/,"").replace(/\s+$/,"");var d=a.split("\r\n\r\n");1==d.length&&(d=a.split("\n\n"));for(a=0;a<d.length;a++)if("WEBVTT"!=d[a]){var e,l=d[a];e={};var q=l.split("\r\n");1==q.length&&(q=l.split("\n"));try{l=1;0<q[0].indexOf(" --\x3e ")&&(l=0);var n=q[l].indexOf(" --\x3e ");0<n&&(e.begin=
h(q[l].substr(0,n)),e.end=h(q[l].substr(n+5)));if(q[l+1]){e.text=q[l+1];for(l+=2;l<q.length;l++)e.text+="\x3cbr/\x3e"+q[l]}}catch(u){}e.text&&(b.push(e),e.end&&(b.push({begin:e.end,text:""}),delete e.end))}1<b.length?f(b):c("Invalid SRT file: "+j)}var d,j,e=jwplayer.utils,h=e.seconds;this.load=function(g){j=g;try{var f;f=g&&0<=g.indexOf("://")&&g.split("/")[2]!=window.location.href.split("/")[2]?!0:!1;f&&e.exists(window.XDomainRequest)&&(d=new XDomainRequest,d.onload=function(){a(d.responseText)},
d.onerror=function(){b(d.status)});d.open("GET",g,!0);d.send(null)}catch(h){c("Error loading SRT File: "+g)}};d=new XMLHttpRequest;d.onreadystatechange=function(){4===d.readyState&&(200===d.status?a(d.responseText):b(d.status))}}})(jwplayer.html5.parsers);
(function(e){var f=jwplayer.utils,c=jwplayer.events,b=c.state,a=f.css,d="playing",j=document;e.captions=function(a,h){function g(a){f.log("CAPTIONS("+a+")")}function t(a){(C=a.fullscreen)?(k(),setTimeout(k,500)):y()}function k(){var a=A.offsetHeight,c=A.offsetWidth;0!=a&&0!=c&&p.resize(c,Math.round(0.94*a))}function s(a){("tt"==e.parsers.localName(a.responseXML.firstChild)?new jwplayer.html5.parsers.dfxp(q,g):new jwplayer.html5.parsers.srt(q,g)).load(G)}function l(){(new jwplayer.html5.parsers.srt(q,
g)).load(G)}function q(a){p.populate(a);B[v].data=a;y()}function y(){if(B.length)if(x==d&&0<D)if(p.show(),C)t({fullscreen:!0});else{var a=m.jwGetWidth();m._model&&(m._model.config&&m._model.config.listbar&&m._model.config.listbar.size)&&(a-=m._model.config.listbar.size);p.resize(a,Math.round(0.94*m.jwGetHeight()))}else p.hide();else p.hide()}function u(){var a=[];a.push({label:"(Off)"});for(var c=0;c<B.length;c++)a.push({label:B[c].label});return a}var m=a,A,r={back:!0,color:"#FFFFFF",fontSize:15},
w={fontFamily:"Arial,sans-serif",fontStyle:"normal",fontWeight:"normal",textDecoration:"none"},p,x,v,B=[],D=0,C=!1,G,z=new c.eventdispatcher;f.extend(this,z);this.element=function(){return A};this.getCaptionsList=function(){return u()};this.getCurrentCaptions=function(){return D};this.setCurrentCaptions=function(a){if(0<=a&&D!=a&&a<=B.length){0<a?(v=a-1,D=a):D=0;B[v].data?p.populate(B[v].data):(G=a=B[v].file,f.ajax(a,s,l));y();a=c.JWPLAYER_CAPTIONS_CHANGED;var b=u();z.sendEvent(a,{type:a,tracks:b,
track:D})}};A=j.createElement("div");A.id=m.id+"_caption";A.className="jwcaptions";m.jwAddEventListener(c.JWPLAYER_PLAYER_STATE,function(a){switch(a.newstate){case b.IDLE:x="idle";y();break;case b.PLAYING:x=d,y()}});m.jwAddEventListener(c.JWPLAYER_PLAYLIST_ITEM,function(){v=0;B=[];p.update(0);var a=m.jwGetPlaylist()[m.jwGetPlaylistIndex()].captions,b=0,d="",f="";if(a)for(b=0;b<a.length;b++)if(f=a[b].file)a[b].label?B.push(a[b]):(d=f.substring(f.lastIndexOf("/")+1,f.indexOf(".")),B.push({file:f,label:d}));
D=0;y();a=c.JWPLAYER_CAPTIONS_LIST;b=u();z.sendEvent(a,{type:a,tracks:b,track:D})});m.jwAddEventListener(c.JWPLAYER_MEDIA_ERROR,g);m.jwAddEventListener(c.JWPLAYER_ERROR,g);m.jwAddEventListener(c.JWPLAYER_READY,function(){for(var a in r)h&&void 0!=h[a.toLowerCase()]?"color"==a?w.color="#"+String(h.color).substr(-6):w[a]=h[a.toLowerCase()]:w[a]=r[a];p=new jwplayer.html5.captions.renderer(w,A);y()});m.jwAddEventListener(c.JWPLAYER_MEDIA_TIME,function(a){p.update(a.position)});m.jwAddEventListener(c.JWPLAYER_FULLSCREEN,
t)};a(".jwcaptions",{position:"absolute",cursor:"pointer",width:"100%",height:"100%",overflow:"hidden"})})(jwplayer.html5);
(function(e){e.captions.renderer=function(f,c){function b(c){e({left:"0px",top:"0px"});g.innerHTML=c;s=""==c?"hidden":"visible";setTimeout(a,20)}function a(){e({left:"0px",top:"0px"});var a=Math.round(f.fontSize*Math.pow(l/400,0.6)),c=Math.round(1.4*a);e({maxWidth:l+"px",fontSize:a+"px",lineHeight:c+"px",visibility:s});a=Math.round(l/2-g.clientWidth/2);c=Math.round(n-g.clientHeight);e({left:a+"px",top:c+"px"})}function d(){for(var a=-1,c=0;c<h.length;c++)if(h[c].begin<=k&&(c==h.length-1||h[c+1].begin>=
k)){a=c;break}-1==a?b(""):a!=t&&(t=a,b(h[c].text))}function e(a){for(var c in a)g.style[c]=a[c]}var n,h,g,t,k,s="visible",l;this.hide=function(){e({display:"none"})};this.populate=function(a){t=-1;h=a;d()};this.resize=function(c,b){l=c;n=b;a()};g=document.createElement("div");c.appendChild(g);e({color:"#"+f.color.substr(-6),display:"block",fontFamily:f.fontFamily,fontStyle:f.fontStyle,fontWeight:f.fontWeight,height:"auto",margin:"0 0 0 0",padding:"3px 9px",position:"absolute",textAlign:"center",textDecoration:f.textDecoration,
wordWrap:"break-word",width:"auto"});f.back?e({background:"#000"}):e({textShadow:"-2px 0px 1px #000,2px 0px 1px #000,0px -2px 1px #000,0px 2px 1px #000,-1px 1px 1px #000,1px 1px 1px #000,1px -1px 1px #000,1px 1px 1px #000"});this.show=function(){e({display:"block"});a()};this.update=function(a){k=a;h&&d()}}})(jwplayer.html5);
(function(e){var f=e.html5,c=e.utils,b=e.events,a=b.state,d=c.css;e=c.transitionStyle;var j="button",n="text",h="divider",g="slider",t="100%",k={display:"none"},s={display:u},l=!1,q=!0,y=null,u=void 0,m=window,A=document;f.controlbar=function(e,w){function p(a,c,b){return{name:a,type:c,className:b}}function x(a){var b=l,d;E.elapsed&&(d=c.timeFormat(a.position),E.elapsed.innerHTML=d,b=d.length!=c.timeFormat(ta).length);E.duration&&(d=c.timeFormat(a.duration),E.duration.innerHTML=d,b=b||d.length!=c.timeFormat(na).length);
0<a.duration?Q(a.position/a.duration):Q(0);na=a.duration;ta=a.position;b&&Da()}function v(){var a=F.jwGetMute();W("mute",a);ua(a?0:xa)}function B(){xa=F.jwGetVolume()/100;ua(xa)}function D(a){ya=a.currentQuality;da&&0<=ya&&da.setActive(a.currentQuality)}function C(a){fa&&(Ea=a.track,ea&&0<=Ea&&ea.setActive(a.track))}function G(){Z=c.extend({},ga,O.getComponentSettings("controlbar"),w);za=I("background").height;d("#"+$,{height:za,bottom:va?0:Z.margin});d(z(".jwtext"),{font:Z.fontsize+"px/"+I("background").height+
"px "+Z.font,color:Z.fontcolor,"font-weight":Z.fontweight});d(z(".jwoverlay"),{bottom:za});0<Z.maxwidth&&d(z(),{"max-width":Z.maxwidth})}function z(a){return"#"+$+(a?" "+a:"")}function J(){return A.createElement("span")}function M(a){switch(a.type){case h:var b;a.width?(b=J(),b.className="jwblankDivider",d(b,{width:parseInt(a.width)})):a.element?b=H(a.element):(b=H(a.name),b||(b=J(),b.className="jwblankDivider"));a.className&&(b.className+=" "+a.className);return b;case n:a=a.name;b={};var e=I(a+
"Background");if(e.src){var k=J();k.id=$+"_"+a;k.className="jwtext jw"+a;b.background="url("+e.src+") no-repeat center";b["background-size"]="100% "+I("background").height+"px";d(z(".jw"+a),b);k.innerHTML="00:00";a=E[a]=k}else a=null;return a;case j:if("blank"!=a.name)return a=a.name,I(a+"Button").src?(b=J(),b.className="jw"+a+" jwbuttoncontainer",e=A.createElement("button"),e.addEventListener("click",R(a),l),e.innerHTML="\x26nbsp;",b.appendChild(e),e=I(a+"Button"),k=I(a+"ButtonOver"),K(z(".jw"+a+
" button"),e,k),(e=Wa[a])&&K(z(".jw"+a+".jwtoggle button"),I(e+"Button"),I(e+"ButtonOver")),a=E[a]=b):a=y,a;break;case g:e=a.name;a=J();var p=e+("time"==e?"Slider":"")+"Cap",r=(k="volume"==e)?"Top":"Left",q=k?"Bottom":"Right",G=H(p+r,y,l,l,k),m=H(p+q,y,l,l,k);b=J();var C=["Rail","Buffer","Progress"],D;b.className="jwrail jwsmooth";for(var w=0;w<C.length;w++){var s="time"==e?"Slider":"",v=e+s+C[w],x=H(v,y,!k,"volume"==e),B=H(v+"Cap"+r,y,l,l,k),W=H(v+"Cap"+q,y,l,l,k),aa=I(v+"Cap"+r),ia=I(v+"Cap"+q);
if(x){var M=J();M.className="jwrailgroup "+C[w];B&&M.appendChild(B);M.appendChild(x);W&&(M.appendChild(W),W.className+=" jwcap"+(k?"Bottom":"Right"));d(z(".jwrailgroup."+C[w]),{"min-width":k?u:aa.width+ia.width});M.capSize=k?aa.height+ia.height:aa.width+ia.width;d(z("."+x.className),{left:k?u:aa.width,right:k?u:ia.width,top:k?aa.height:u,bottom:k?ia.height:u,height:k?"auto":u});2==w&&(D=M);E[v]=M;b.appendChild(M)}}if(s=H(e+s+"Thumb",y,l,l,k))d(z("."+s.className),{opacity:"time"==e?0:1,"margin-top":k?
s.skin.height/-2:u}),s.className+=" jwthumb",(k&&D?D:b).appendChild(s);b.addEventListener("mousedown",Aa(e),l);"time"==e&&(b.addEventListener("mousemove",L,l),b.addEventListener("mouseout",U,l));E[e+"Rail"]=b;D=I(p+r);p=I(p+r);I(e+"SliderRail");a.className="jwslider jw"+e;G&&a.appendChild(G);a.appendChild(b);m&&(k&&(m.className+=" jwcapBottom"),a.appendChild(m));d(z(".jw"+e+" .jwrail"),{left:k?u:D.width,right:k?u:p.width,top:k?D.height:u,bottom:k?p.height:u,width:k?t:u,height:k?"auto":u});E[e]=a;
a.vertical=k;"time"==e?(ra=new f.overlay($+"_timetooltip",O),Fa=A.createElement("div"),Fa.className="jwoverlaytext",ra.setContents(Fa),Pa=b,Fa.innerHTML=c.timeFormat(0),e=ra.element(),b.appendChild(e),E.timeSliderThumb&&d(z(".jwtimeSliderThumb"),{"margin-left":I("timeSliderThumb").width/-2}),V(0),Q(0),Q(0),V(0)):"volume"==e&&(d(z(".jwvolume"),{width:I("volumeRail").width+(k?0:I("volumeCap"+r).width+I("volumeCap"+q).width),height:k?I("volumeCap"+r).height+I("volumeRail").height+I("volumeRailCap"+r).height+
I("volumeRailCap"+q).height+I("volumeCap"+q).height:u}),k&&(a.className+=" jwvertical"));return a}}function H(a,b,e,f,g){var k=J();k.className="jw"+a;var h=f?" left center":" center";f=I(a);k.innerHTML="\x26nbsp;";if(f&&""!=f.src)return e=e?{background:"url('"+f.src+"') repeat-x "+h,height:g?f.height:u}:{background:"url('"+f.src+"') no-repeat"+h,width:f.width,height:g?f.height:u},k.skin=f,d(z(".jw"+a),c.extend(e,b)),E[a]=k}function K(a,b,c){b.src&&(d(a,{width:b.width,background:"url("+b.src+") center no-repeat"}),
c.src&&d(a+":hover",{background:"url("+c.src+") center no-repeat"}))}function R(a){return function(){if(Qa[a])Qa[a]()}}function X(a){for(var b in oa)b!=a&&oa.hasOwnProperty(b)&&oa[b].hide()}function N(){va||(aa.show(),X("volume"))}function Y(){va||(Ga.show(),X("fullscreen"))}function W(a,b){c.exists(b)||(b=!La[a]);E[a]&&(E[a].className="jw"+a+(b?" jwtoggle jwtoggling":" jwtoggling"),setTimeout(function(){E[a].className=E[a].className.replace(" jwtoggling","")},100));La[a]=b}function ha(){ba&&1<ba.length&&
(Ma&&(clearTimeout(Ma),Ma=void 0),da.show(),X("hd"))}function Ha(){fa&&1<fa.length&&(Na&&(clearTimeout(Na),Na=void 0),ea.show(),X("cc"))}function Ba(a){0<=a&&a<ba.length&&(F.jwSetCurrentQuality(a),da.hide())}function ia(a){0<=a&&a<fa.length&&(F.jwSetCurrentCaptions(a),ea.hide())}function Ia(a){a.preventDefault();A.onselectstart=function(){return l}}function Aa(b){return function(c){0==c.button&&(E[b+"Rail"].className="jwrail","time"==b?F.jwGetState()!=a.IDLE&&(F.jwSeekDrag(q),ja=b):ja=b)}}function P(a){var b=
(new Date).getTime();if(50<b-Ra){if((Ja=c.bounds(Pa))&&0!=Ja.width){var d=ra.element(),e=a.pageX-Ja.left-m.pageXOffset;0<=e&&e<=Ja.width&&(d.style.left=Math.round(e)+"px",Fa.innerHTML=c.timeFormat(na*e/Ja.width))}Ra=b}if(ja&&0==a.button)return d=E[ja].getElementsByClassName("jwrail")[0],e=c.bounds(d),d=ja,e=E[d].vertical?(e.bottom-a.pageY)/e.height:(a.pageX-e.left)/e.width,"mouseup"==a.type?("time"==d&&F.jwSeekDrag(l),E[d+"Rail"].className="jwrail jwsmooth",ja=y,Sa[d](e)):("time"==ja?Q(e):ua(e),500<
b-Ta&&(Ta=b,Sa[ja](e))),!1}function L(){ra&&(na&&!va)&&ra.show()}function U(){ra&&ra.hide()}function pa(){Na=setTimeout(ea.hide,500)}function ca(){Ma=setTimeout(da.hide,500)}function sa(a,b,c,e){var f=a.element();b.appendChild(f);b.addEventListener("mousemove",c,l);e?b.addEventListener("mouseout",e,l):b.addEventListener("mouseout",a.hide,l);d("#"+f.id,{left:"50%"})}function qa(a){var b=J();b.className="jwgroup jw"+a;wa[a]=b;if(S[a]&&(b=S[a],a=wa[a],b&&0<b.elements.length))for(var c=0;c<b.elements.length;c++){var d=
M(b.elements[c]);d&&("volume"==b.elements[c].name&&d.vertical?(aa=new f.overlay($+"_volumeOverlay",O),aa.setContents(d)):a.appendChild(d))}}function Oa(){1<F.jwGetPlaylist().length&&(!A.querySelector("#"+F.id+" .jwplaylist")||F.jwGetFullscreen())?(d(z(".jwnext"),s),d(z(".jwprev"),s),d(z(".nextdiv"),s)):(d(z(".jwnext"),k),d(z(".jwprev"),k),d(z(".nextdiv"),k))}function V(a){a=Math.min(Math.max(0,a),1);E.timeSliderBuffer&&(E.timeSliderBuffer.style.width=100*a+"%",E.timeSliderBuffer.style.opacity=0<a?
1:0)}function ka(a,b){var c=E[a].vertical,d=a+("time"==a?"Slider":""),e=100*Math.min(Math.max(0,b),1)+"%",f=E[d+"Progress"],d=E[d+"Thumb"],k=l;f&&(c?(f.style.height=e,f.style.bottom=0,f.clientHeight<=f.capSize&&(k=q)):(f.style.width=e,f.clientWidth<=f.capSize&&(k=q)),f.style.opacity=!k&&0<b||ja?1:0);d&&(c?d.style.top=0:d.style.left=e)}function ua(a){ka("volume",a)}function Q(a){ka("time",a)}function I(a){return(a=O.getSkinElement(0==a.indexOf("volume")?"tooltip":"controlbar",a))?a:{width:0,height:0,
src:"",image:u,ready:l}}var F,O,la=p("divider",h),ga={margin:8,maxwidth:800,font:"Arial,sans-serif",fontsize:11,fontcolor:15658734,fontweight:"bold",layout:{left:{position:"left",elements:[p("play",j),la,p("prev",j),p("next",j),p("divider",h,"nextdiv"),p("elapsed",n)]},center:{position:"center",elements:[p("time",g)]},right:{position:"right",elements:[p("duration",n),la,p("hd",j),p("cc",j),la,p("mute",j),p("volume",g),la,p("fullscreen",j)]}}},Z,S,E,za,T,$,na,ta,ba,ya,fa,Ea,xa,aa,Ka,Pa,Ja,ra,Fa,Ma,
da,Na,ea,Ga,Ua,va=l,ja=l,Ta=0,Ra=0,Wa={play:"pause",mute:"unmute",fullscreen:"normalscreen"},La={play:l,mute:l,fullscreen:l},Qa={play:function(){La.play?F.jwPause():F.jwPlay()},mute:function(){F.jwSetMute();v({mute:La.mute})},fullscreen:function(){F.jwSetFullscreen()},next:function(){F.jwPlaylistNext()},prev:function(){F.jwPlaylistPrev()}},Sa={time:function(a){F.jwSeek(a*na)},volume:function(a){ua(a);0.1>a&&(a=0);0.9<a&&(a=1);F.jwSetVolume(100*a)}},oa={},ma=this,wa={},Da=function(){clearTimeout(Ua);
Ua=setTimeout(ma.redraw,0)};ma.redraw=function(){G();var a=I("capLeft"),b=I("capRight");d(z(".jwgroup.jwcenter"),{left:Math.round(c.parseDimension(wa.left.offsetWidth)+a.width),right:Math.round(c.parseDimension(wa.right.offsetWidth)+b.width)});a=T.parentNode.clientWidth>Z.maxwidth;b=va?0:Z.margin;d(z(),{left:a?"50%":b,right:a?u:b,"margin-left":a?T.clientWidth/-2:u,width:a?t:u});var e;Ka=c.bounds(T);for(e in oa)b=oa[e],b.offsetX(0),a=c.bounds(b.element()),a.right>Ka.right?b.offsetX(Ka.right-a.right):
a.left<Ka.left&&b.offsetX(Ka.left-a.left)};ma.audioMode=function(a){a!=va&&(va=a,d(z(".jwfullscreen"),{display:a?"none":u}),d(z(".jwhd"),{display:a?"none":u}),d(z(".jwcc"),{display:a?"none":u}),Da())};ma.element=function(){return T};ma.margin=function(){return parseInt(Z.margin)};ma.show=function(){ma.visible=!0;T.style.opacity=1};ma.hide=function(){ma.visible=!1;T.style.opacity=0};E={};F=e;$=F.id+"_controlbar";na=ta=0;T=J();T.id=$;T.className="jwcontrolbar";O=F.skin;S=O.getComponentLayout("controlbar");
S||(S=ga.layout);c.clearCss("#"+$);G();var Ca=H("capLeft"),la=H("capRight"),Va=H("background",{position:"absolute",left:I("capLeft").width,right:I("capRight").width,"background-repeat":"repeat-x"},q);Va&&T.appendChild(Va);Ca&&T.appendChild(Ca);qa("left");qa("center");qa("right");T.appendChild(wa.left);T.appendChild(wa.center);T.appendChild(wa.right);E.hd&&(da=new f.menu("hd",$+"_hd",O,Ba),sa(da,E.hd,ha,ca),oa.hd=da);E.cc&&(ea=new f.menu("cc",$+"_cc",O,ia),sa(ea,E.cc,Ha,pa),oa.cc=ea);E.mute&&(E.volume&&
E.volume.vertical)&&(aa=new f.overlay($+"_volumeoverlay",O),aa.setContents(E.volume),sa(aa,E.mute,N),oa.volume=aa);E.fullscreen&&(Ga=new f.overlay($+"_fullscreenoverlay",O),Ca=A.createElement("div"),Ca.className="jwoverlaytext",Ca.innerHTML="Fullscreen",Ga.setContents(Ca),sa(Ga,E.fullscreen,Y),oa.fullscreen=Ga);d(z(".jwright"),{right:I("capRight").width});la&&T.appendChild(la);F.jwAddEventListener(b.JWPLAYER_MEDIA_TIME,x);F.jwAddEventListener(b.JWPLAYER_PLAYER_STATE,function(b){switch(b.newstate){case a.BUFFERING:case a.PLAYING:d(z(".jwtimeSliderThumb"),
{opacity:1});W("play",q);break;case a.PAUSED:ja||W("play",l);break;case a.IDLE:W("play",l),d(z(".jwtimeSliderThumb"),{opacity:0}),E.timeRail&&(E.timeRail.className="jwrail",setTimeout(function(){E.timeRail.className+=" jwsmooth"},100)),V(0),x({position:0,duration:0})}});F.jwAddEventListener(b.JWPLAYER_MEDIA_MUTE,v);F.jwAddEventListener(b.JWPLAYER_MEDIA_VOLUME,B);F.jwAddEventListener(b.JWPLAYER_MEDIA_BUFFER,function(a){V(a.bufferPercent/100)});F.jwAddEventListener(b.JWPLAYER_FULLSCREEN,function(a){W("fullscreen",
a.fullscreen);Oa()});F.jwAddEventListener(b.JWPLAYER_PLAYLIST_LOADED,function(){d(z(".jwhd"),k);d(z(".jwcc"),k);Oa();Da()});F.jwAddEventListener(b.JWPLAYER_MEDIA_LEVELS,function(a){if((ba=a.levels)&&1<ba.length&&da){d(z(".jwhd"),{display:u});da.clearOptions();for(var b=0;b<ba.length;b++)da.addOption(ba[b].label,b);D(a)}else d(z(".jwhd"),{display:"none"});Da()});F.jwAddEventListener(b.JWPLAYER_MEDIA_LEVEL_CHANGED,D);F.jwAddEventListener(b.JWPLAYER_CAPTIONS_LIST,function(a){if((fa=a.tracks)&&1<fa.length&&
ea){d(z(".jwcc"),{display:u});ea.clearOptions();for(var b=0;b<fa.length;b++)ea.addOption(fa[b].label,b);C(a)}else d(z(".jwcc"),{display:"none"});Da()});F.jwAddEventListener(b.JWPLAYER_CAPTIONS_CHANGED,C);T.addEventListener("mouseover",function(){m.addEventListener("mousemove",P,l);m.addEventListener("mouseup",P,l);m.addEventListener("mousedown",Ia,l)},!1);T.addEventListener("mouseout",function(){m.removeEventListener("mousemove",P);m.removeEventListener("mouseup",P);m.removeEventListener("mousedown",
Ia);A.onselectstart=null},!1);setTimeout(function(){B();v()},0);ma.visible=!1};d(".jwcontrolbar",{position:"absolute",opacity:0});d(".jwcontrolbar span",{height:t});c.dragStyle(".jwcontrolbar span","none");d(".jwcontrolbar .jwgroup",{display:"inline"});d(".jwcontrolbar span, .jwcontrolbar .jwgroup button,.jwcontrolbar .jwleft",{position:"relative","float":"left"});d(".jwcontrolbar .jwright",{position:"absolute"});d(".jwcontrolbar .jwcenter",{position:"absolute"});d(".jwcontrolbar buttoncontainer,.jwcontrolbar button",
{display:"inline-block",height:t,border:"none",cursor:"pointer"});d(".jwcontrolbar .jwcapRight,.jwcontrolbar .jwtimeSliderCapRight,.jwcontrolbar .jwvolumeCapRight",{right:0,position:"absolute"});d(".jwcontrolbar .jwcapBottom",{bottom:0,position:"absolute"});d(".jwcontrolbar .jwtime",{position:"absolute",height:t,width:t,left:0});d(".jwcontrolbar .jwthumb",{position:"absolute",height:t,cursor:"pointer"});d(".jwcontrolbar .jwrail",{position:"absolute",cursor:"pointer"});d(".jwcontrolbar .jwrailgroup",
{position:"absolute",width:t});d(".jwcontrolbar .jwrailgroup span",{position:"absolute"});d(".jwcontrolbar .jwdivider+.jwdivider",{display:"none"});d(".jwcontrolbar .jwtext",{padding:"0 5px","text-align":"center"});d(".jwcontrolbar .jwoverlaytext",{padding:3});d(".jwcontrolbar .jwvertical *",{display:"block"});e(".jwcontrolbar","opacity .15s, background .15s, visibility .15s");e(".jwcontrolbar button","opacity .15s, background .15s, visibility .15s");e(".jwcontrolbar .jwtime .jwsmooth span","opacity .15s, background .15s, visibility .15s, width .15s linear, left .15s linear");
e(".jwcontrolbar .jwtoggling","none")})(jwplayer);
(function(e){var f=e.html5,c=e.utils,b=e.events,a=b.state;f.controller=function(d,j){function n(a){r.sendEvent(a.type,a)}function h(a){t(!0);switch(c.typeOf(a)){case "string":var d=new f.playlistloader;d.addEventListener(b.JWPLAYER_PLAYLIST_LOADED,function(a){h(a.playlist)});d.addEventListener(b.JWPLAYER_ERROR,function(a){h([]);a.message="Could not load playlist: "+a.message;n(a)});d.load(a);break;case "object":case "array":m.setPlaylist(new e.playlist(a));break;case "number":m.setItem(a)}}function g(d){c.exists(d)||
(d=!0);if(!d)return k();try{0<=p&&(h(p),p=-1);v=g;if(!x&&(x=!0,r.sendEvent(b.JWPLAYER_MEDIA_BEFOREPLAY),x=!1,D)){D=!1;v=null;return}if(m.state==a.IDLE){if(0==m.playlist.length)return!1;A.load(m.playlist[m.item])}else m.state==a.PAUSED&&A.play();return!0}catch(e){r.sendEvent(b.JWPLAYER_ERROR,e),v=null}return!1}function t(c){v=null;try{return m.state!=a.IDLE?A.stop():c||(B=!0),x&&(D=!0),!0}catch(d){r.sendEvent(b.JWPLAYER_ERROR,d)}return!1}function k(d){v=null;c.exists(d)||(d=!0);if(!d)return g();try{switch(m.state){case a.PLAYING:case a.BUFFERING:A.pause();
break;default:x&&(D=!0)}return!0}catch(e){r.sendEvent(b.JWPLAYER_ERROR,e)}return!1}function s(a){h(a);g()}function l(){s(m.item+1)}function q(){m.state==a.IDLE&&(B?B=!1:(v=q,m.repeat?l():m.item==m.playlist.length-1?(p=0,t(!0),setTimeout(function(){r.sendEvent(b.JWPLAYER_PLAYLIST_COMPLETE)},0)):l()))}function y(a){return function(){w?u(a,arguments):C.push({method:a,arguments:arguments})}}function u(a,b){var c=[];for(i=0;i<b.length;i++)c.push(b[i]);a.apply(this,c)}var m=d,A=d.getVideo(),r=new b.eventdispatcher(m.id,
m.config.debug),w=!1,p=-1,x,v,B=!1,D,C=[];c.extend(this,r);this.play=y(g);this.pause=y(k);this.seek=y(function(b){m.state!=a.PLAYING&&g(!0);A.seek(b)});this.stop=function(){B=!0;y(t)()};this.load=y(h);this.next=y(l);this.prev=y(function(){s(m.item-1)});this.item=y(s);this.setVolume=y(m.setVolume);this.setMute=y(m.setMute);this.setFullscreen=y(function(a){j.fullscreen(a)});this.setStretching=y(function(a){m.stretching=a;j.resize()});this.detachMedia=function(){try{return m.getVideo().detachMedia()}catch(a){return null}};
this.attachMedia=function(){try{m.getVideo().attachMedia(),"function"==typeof v&&v()}catch(a){return null}};this.setCurrentQuality=y(function(a){A.setCurrentQuality(a)});this.getCurrentQuality=function(){return A?A.getCurrentQuality():-1};this.getQualityLevels=function(){return A?A.getQualityLevels():null};this.setCurrentCaptions=y(function(a){j.setCurrentCaptions(a)});this.getCurrentCaptions=function(){return j.getCurrentCaptions()};this.getCaptionsList=function(){return j.getCaptionsList()};this.playerReady=
function(a){if(!w){j.completeSetup();r.sendEvent(a.type,a);e.utils.exists(window.jwplayer.playerReady)&&e.playerReady(a);m.addGlobalListener(n);j.addGlobalListener(n);r.sendEvent(e.events.JWPLAYER_PLAYLIST_LOADED,{playlist:m.playlist});r.sendEvent(e.events.JWPLAYER_PLAYLIST_ITEM,{index:m.item});h();m.autostart&&!c.isMobile()&&g();for(w=!0;0<C.length;)a=C.shift(),u(a.method,a.arguments)}};m.addEventListener(b.JWPLAYER_MEDIA_BUFFER_FULL,function(){A.play()});m.addEventListener(b.JWPLAYER_MEDIA_COMPLETE,
function(){setTimeout(q,25)});m.addEventListener(b.JWPLAYER_MEDIA_ERROR,function(a){a=c.extend({},a);a.type=b.JWPLAYER_ERROR;r.sendEvent(a.type,a)})}})(jwplayer);
(function(e){e.html5.defaultskin=function(){this.text='\x3c?xml version\x3d"1.0" ?\x3e\x3cskin author\x3d"LongTail Video" name\x3d"Six" version\x3d"2.0" target\x3d"6.0"\x3e\x3ccomponents\x3e\x3ccomponent name\x3d"controlbar"\x3e\x3csettings\x3e\x3csetting name\x3d"margin" value\x3d"8"/\x3e\x3csetting name\x3d"fontcolor" value\x3d"eeeeee"/\x3e\x3csetting name\x3d"fontsize" value\x3d"11"/\x3e\x3csetting name\x3d"fontweight" value\x3d"bold"/\x3e\x3csetting name\x3d"maxwidth" value\x3d"800"/\x3e\x3c/settings\x3e\x3celements\x3e\x3celement name\x3d"background" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAAaCAIAAAD5ZqGGAAAAJklEQVR42mNKSUlhevToEdPXr1+Z/v37RxH+//8/htjv379BZgMA4j5LOzqaqAsAAAAASUVORK5CYII\x3d"/\x3e\x3celement name\x3d"capLeft" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAUAAAAaCAYAAAB/75arAAAAh0lEQVR42t2RywnDMAxAhSbJRukGPtgDdJSO0k7U4IOPBhuM8b9SIAG3p0JPFTwETxJICIFCSrkqpZ7EYFAIsbbW7s65RWsNDJK4ee/BGAMhhB2stS7WWui9n7CEGOMsaXwSZ+d/yR+cOcaY+HL8vcByyzl/7HllyX8qpexgSulBhQvl7XjxCydafIt3Z4BrAAAAAElFTkSuQmCC"/\x3e\x3celement name\x3d"capRight" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAUAAAAaCAYAAAB/75arAAAAjUlEQVR42tWRywnDMAxAhSbJRukGPtgDdJSO0k7U4INPvthgjP+VSlsSkkvpqYKH4EnCFkKl1Hhxl1LOQIFaa2Ccc1Nr7SqEmDGEAIwxBrz3QIUL9t7hjbUWaq3TRqaUWMJGMjS+l4edfy2/XHOMAWt+eJ3FTuacWS5YSgEmxviU9M/z58R0tIXEifLtATSUfIsSwhegAAAAAElFTkSuQmCC"/\x3e\x3celement name\x3d"divider" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAAaCAYAAAB2BDbRAAAAEElEQVR42mP4//8/A8NAEgDiqk2zfDlcXgAAAABJRU5ErkJggg\x3d\x3d"/\x3e\x3celement name\x3d"playButton" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABgAAAAcCAYAAAB75n/uAAAAdUlEQVR42u2TsQ3AIAwE2YARMkJGyCiMwiiMwgjUFMAIjOC8lMJdiIjd+aSrr3i9MwzjHXoYMOgFmAIvvQCT4aEXYNLvEK2ZMEKvFODQVqC1Rl/sve8Faq20cMIIvUYgQR5ZMJDh6RixQIF8NMHAgMEZhrHNDU+1T3s3o0CaAAAAAElFTkSuQmCC"/\x3e\x3celement name\x3d"playButtonOver" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABgAAAAcCAYAAAB75n/uAAABhUlEQVR42uXVzUoCYRTGcXNGR3HSDPtASyIhrIjaFJlBRBRUdAUGQQurdVfSrl2LuhEvYxR1IYroRhCEWU1/4R2Yxcz4MUlQB34bGc6D58y8r+/vl2EYczNpKvitzN9/orEEGUEoQhAyJDNs2gAJCiKIYVGIQUUIAWvQNM2jWMEGtoRNpJBAFOGJgsRDAahYRRbHuMAVznGEHaSxZBNkvyPLQhXEkUEew+riE88o4AYn2BVBCcxDgWz+G6fxhLGMPdzBWh184RUPuEUOWaSwgBBkpwAZESRxiALsqoV3EXSPSxwgLUIUc1xOAWvI4RFupeENRVxjH0moCMBvF6BiHXkUMap0lPCCM2QQh2LuwingFE8Ytwa4wTYSCEEaGVCtVo1x1Gq1CQPEiDRNM9yUy2W92WyWdF13HJHrkt2aNxoNbTAYuC555Gtq17her7f6/f7HmK+p+4dmbcysO71ez8OHZnNUDBtXKpVuu932clTM/rCb/XHt/cL5/SvT+6XvKcz3r+sbpPMfjCOvfIMAAAAASUVORK5CYII\x3d"/\x3e\x3celement name\x3d"pauseButton" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABgAAAAcCAYAAAB75n/uAAAAN0lEQVR42u3NoQ0AMAwDwe6/YYBncWlUyQFBBX+SickfADM/0k+AQCbJffHfqir3hZ/ADwEAowtQ1mmQzb8rQgAAAABJRU5ErkJggg\x3d\x3d"/\x3e\x3celement name\x3d"pauseButtonOver" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABgAAAAcCAYAAAB75n/uAAABdUlEQVR42t2WzWrCQBSFq1FSaSjaFi1iF6UFtdBdF6WhC0Hoym3BlSAu+wbddSF9xfyTJ7k9gRMJuY2Oi2w88BG5zLlHZiYzOTttiUijyP768Y2bxCKVv0nD+B/T2AY2OAcdPnOKNZtjrdx/KMCi6QJ0wTW44fOKFGtdjrXzEJPml2AA7sEEPIExeCRj1iYcM6CnOoTz2AYOuAVT8Arm4APMwDuZsTbnmCk9Dns0qxbVBj3wAFzR+iRlufT02IOLrqenA/rgGSxE64uUtaCnzx7WfwEtLtYQvIClaH2Tspb0DNmjtS9gxHldidYPKWtFz+hQgAPuwBtYi9aWlLXOPPQ6JgEu2IjWLylrQ89xAVEUSRzHkiSJpGm6C8jqBVSA8RR5nie+70sQBHmjbUZWL6CmyHiRVQAXWQfoRTbapiqA21QH6G1q9KJl5jwkDMPdi6YCzF40fVSoAB4VKqDiqKj1sKv9uK71wqn9yqzt0q/vs+Wk9QeSkdKwXIKzCgAAAABJRU5ErkJggg\x3d\x3d"/\x3e\x3celement name\x3d"prevButton" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAAcCAYAAABsxO8nAAAAfUlEQVR42u2MwQnAIAxFu4EjOIIjOFJH6EiCF8fw7BQZwf5AegkU2tje8uGR5Afe5vH8mTHGZG5+EXSzSPoMCEyzCPd+9SYRZgCFb7MIJNB5XxURT7OotTYFkql5Jqq1TiGBzrvinUj2AMqSSHXHikj3GZBVpH8R9M3j+Tgn8lcGnlSSd08AAAAASUVORK5CYII\x3d"/\x3e\x3celement name\x3d"prevButtonOver" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAAcCAYAAABsxO8nAAABhUlEQVR42uXUz0oCURTH8VKz/BNFmZJ/iMAoEmohlRRI7Yp2Qa0igyJc9Qot2vUGbnwB3yJXPYKaCi5m62LQzSymr3KE09hAi1nVgQ93hnv4wZ259878o7Jte/YXfADPcAvwIeDgFwHMKYFJoDPILw0hREQYCyKMKBZlDCEIvzMkiAhWEEdCxlURRwoZJBGTwOA4SC0nLJMb2MGujFlsIYc8DrCPrIRHZtR3mccSMtI0qTMUcYoLXKGMTxxiE8t6WSHEsI2iCirhDg94RgVDmTtHDmvjILWsBPZwqYJe8Io3vEPXDfJY10ERJGXiWjVXUYMBZ5VQQMoZlMIRblVzHSZ+qkccI62DokijgHvVbMGtnnCCjGtQu922R7rdriXPU3SQ69IajYY9MhgM6p1Ox5R3zbE0l4+tmquWZdV6vZ7hDNIf2/X3T5r17zcM40MH6d/vuiGleWpD9vv9SrPZHDLn2JAuR0QFTR0R0zTLrVbr2xHx7NB6do14drF5dtV6c/n/7foCpva8IJ04vWUAAAAASUVORK5CYII\x3d"/\x3e\x3celement name\x3d"nextButton" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAAcCAYAAABsxO8nAAAAdklEQVR42u3OwQnAIAyF4WzgCB3BERypI3QkwYtjeHaKjGBfIeClFmvaWx58KAg/ks329WqtBbbBW7vMhhowBH2o2/WhLoJTh0QBrw4JfhXKObcBlnMulFJqNwp4uS+HIjjCNKGDZKshhkCYJlRge/ot2Ww/7gSJGQaejWvrvwAAAABJRU5ErkJggg\x3d\x3d"/\x3e\x3celement name\x3d"nextButtonOver" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAAcCAYAAABsxO8nAAABjElEQVR42uXUPUvDQBwGcNvUatOK4kuKfUEERVGwg/iCguimuAk6iQqKOPkVHLr5DVz8An4LO/kR2jQtZMjaIbRLhvOpPOHOJMahnfQPP5IcyXO5S+5G/ngJIRKUpMRvwiEyIAWjPl5rlApIhgJ5YxoykIMJHnUYJx2ylGFHWjAozQdnoQBlKIIBM2RAnsdpBqa/hbHRgCWowBZswjoss30V1nhcYKe6P0w/aAoWYRua8ABncAKHcABHQlaFbz0JY/589YPm2Psxb+zBCzzCLVzBtWAxeIVvlQHND5rnUC5ArXd4hio8Ke2nsAF5OTwEcWJ32WuwHHiDV6XtnB0XIKsGlWAP7iCqXKgp15ewA8VgUBn24R5+Kk85v+EISpCLDLIsS0Rpt9sez+OC5NDq9boIarVabrfbrfE6bmhysoMhtm07nud9TTbb4iZbfn41xHGcD/Xzsz3u88sfsn9jo9HodTqd0A/JoLgfUi4R0zSbrutGLhEGxS2RwRftMLeRwTe2oW21g2/+/6c+AdO5vCABA1zBAAAAAElFTkSuQmCC"/\x3e\x3celement name\x3d"elapsedBackground" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAAaCAYAAAB2BDbRAAAAEElEQVR42mP4//8/A8NAEgDiqk2zfDlcXgAAAABJRU5ErkJggg\x3d\x3d"/\x3e\x3celement name\x3d"timeSliderCapLeft" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAYAAAAcCAYAAABCgc61AAAAD0lEQVQoFWNgGAWjYGgCAAK8AAEb3eOQAAAAAElFTkSuQmCC"/\x3e\x3celement name\x3d"timeSliderCapRight" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAYAAAAcCAYAAABCgc61AAAAD0lEQVQoFWNgGAWjYGgCAAK8AAEb3eOQAAAAAElFTkSuQmCC"/\x3e\x3celement name\x3d"timeSliderRail" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAQAAAAcCAYAAABGdB6IAAAALElEQVQY02NkQAOMg1aAmZn5P4oALy8vqoCYmBiqgIKCAqqAmpoaxQJDJsQA+54Krz/ExkoAAAAASUVORK5CYII\x3d"/\x3e\x3celement name\x3d"timeSliderRailCapLeft" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAQAAAAcCAYAAABGdB6IAAAAWklEQVR42tWLsQlAIQwFBcVKGyEGK61cJ/tXGeVptPjwN/DgQnIQ9xYxRgkhqPceLqUkW5g5Z7g91BYiQq31BDAzxhjmDb13zDnN+/IP0lr7glFKkX3oCc+wAHpnIpi5hlqoAAAAAElFTkSuQmCC"/\x3e\x3celement name\x3d"timeSliderRailCapRight" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAQAAAAcCAYAAABGdB6IAAAAVklEQVR42tXJMQ4AIQhEURKMFZZCrLDyOty/4ijsYuJWewEn+c0buGeIGKUUr7XahtZaENHJgJmj9x7vkTnMOSMTkY2w1opMVX/BPxhjJNgBFxGDq/YAy/oipxG/oRoAAAAASUVORK5CYII\x3d"/\x3e\x3celement name\x3d"timeSliderBuffer" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAQAAAAcCAYAAABGdB6IAAAAE0lEQVQYV2NgGErgPxoeKIGhAQB1/x/hLROY4wAAAABJRU5ErkJggg\x3d\x3d"/\x3e\x3celement name\x3d"timeSliderBufferCapLeft" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAQAAAAcCAYAAABGdB6IAAAAJ0lEQVQYlWNgGGrAH4jvA/F/GOc/EobLwAX+ExTA0IJhKIa1QwMAAIX5GqOIS3lSAAAAAElFTkSuQmCC"/\x3e\x3celement name\x3d"timeSliderBufferCapRight" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAQAAAAcCAYAAABGdB6IAAAAJ0lEQVQY02NgGErgPxDfB2J/ZAEY9kcXuI8u8J+gwH2chqJYOzQAALXhGqOFxXzUAAAAAElFTkSuQmCC"/\x3e\x3celement name\x3d"timeSliderProgress" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAQAAAAcCAYAAABGdB6IAAAALUlEQVQYV2NgGCqA8T8QIAuwoPEZWD58+IAq8Pr1a1IF3r59iyrw9+9fhqEJABv9F+gP7YohAAAAAElFTkSuQmCC"/\x3e\x3celement name\x3d"timeSliderProgressCapLeft" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAQAAAAcCAYAAABGdB6IAAAASklEQVR42tXDQQ0AIAwDwDqcPhLQgAlM8JqDORilnyVY4JLDX0iaOgWZaeccVkSEKyv23nxjrcU35pyurBhjWO+dFZDWmqkr8Y0Lr65i67XRzKcAAAAASUVORK5CYII\x3d"/\x3e\x3celement name\x3d"timeSliderProgressCapRight" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAQAAAAcCAYAAABGdB6IAAAAS0lEQVQY09XDQQ0AIRAEwXa4+iYBDZjABC8c4ADmHheStUAlBc/wb9oOAM45vvfewVrL6WSM4Zzeu3Naa04npRTftdZAkiVNScFTPhkFYuvY2zeUAAAAAElFTkSuQmCC"/\x3e\x3celement name\x3d"timeSliderThumb" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAoAAAAcCAYAAABYvS47AAAAwElEQVR42tWTPQrCQBCF84OsYJCIYEQrsZAU6QKx9xheyG4L6zTZs3iInGZ9Tx4iAWHaDHwwvPlgyWY2mVvFGNNf/gmZyEUm0q+kwQI4sBROWf6R2ShcgRJsRanM0UnUrEEFTuBC1FeaOYoF2IMaXMGNqK81KyhuwDmEcB/H8RVV7JlxRofiDjTe+0eclLKGDsUDaPu+91NRWUuH4hF0wzA8p6Kyjo5ZNB9t/hjz9Zgv3PwLzUthXjPT4hqewrzqDfMnQ2tu8Pr1AAAAAElFTkSuQmCC"/\x3e\x3celement name\x3d"durationBackground" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAAaCAYAAAB2BDbRAAAAEElEQVR42mP4//8/A8NAEgDiqk2zfDlcXgAAAABJRU5ErkJggg\x3d\x3d"/\x3e\x3celement name\x3d"hdButton" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAB8AAAAcCAMAAACu5JSlAAAAZlBMVEUAAACysrLZ2dkmJiYuLi4xMTE3Nzc8PDxAQEBJSUlRUVFSUlJaWlpdXV1jY2NpaWlsbGx0dHR3d3d4eHh9fX2KioqPj4+SkpKVlZWXl5ehoaGpqamsrKyysrK3t7fCwsLNzc3Z2dkN+/dcAAAAA3RSTlMAf3+Sa81KAAAAh0lEQVQoU+3J0RpCQBCA0dW/i02KpEIzzPu/ZJc+7CM4t8e5k3PuYgmX9VNttv2W2iww9gDhe/iK3mZYHhRVIBwe+l9PYQWjzbB/BYB6gdl096ra4WP0PD/kqh25qq4vIjfuIvBuuMrkaURk8yUvGUAiefSU0/5hkJZSPECcZP8J62epztzpDzcuFrDsGN7pAAAAAElFTkSuQmCC"/\x3e\x3celement name\x3d"hdButtonOver" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAB8AAAAcCAYAAACZOmSXAAACFUlEQVR42u2WsWoCQRCGE42I5AikkSBaGSwsAiIpQi4BK0vF+qwEjb1gaWMlaGfvA5xYWvgCNraChY0+gU+wmR3+DcPGC0lQrnHg43bvbv5/d25v764uYYdS6voc/MY0AqLEzYmICt3roJlGiRgRJxLELXD+g8hPQDPGHnIAwjiOpHsiSaSINMj8CeRBIwlNBx7RY8Z3xAORJZ6IZ+KFeCXcP/KK3GdoZbU2POLGPIJyOLiYJ96ICuERDaJJtIiPX9JCTgMaFWjm4eHIBRZHWR6Jd8JXpw8f2o/aS5Y8QSRRnqo6X1ThkTTmN1iRKTwfz87o9/sql8updrutTBSLRT63WCzUZDLhtoCvT6dTW8qDR8o2T2OBNL5leJ4WZBMd+/3+y+RwOKhut8vtUqnE92JgfLSiAY+0NHeIDFZo085gI5gvl0s+GjMKPpoq2IOzogmPzDFzl1eriPV6zSI2eAw8c/TZ1M6RAW33R/PtdqsMo9GIRQqFgqrVagy1+dxwOFSz2YzbrutaOeIckOaBZd9sNgro2bFQp9Mx575m5fu+6vV63K7X63xttVqZwfE1qSXLHrjgZEK5XGah8XjM/fl8bsx1nyuBWcqq6DweiNSSCy7wVZMJMNKm3B8MBkac+zCT8CBgLLFetYBNBjefHLnJBG6vu93OP7Wx1pTba6gfllA/qaH+TIT6GxXaD2Q4v86XoPgE1h55oNE1QD4AAAAASUVORK5CYII\x3d"/\x3e\x3celement name\x3d"ccButton" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAB0AAAAcCAMAAACqEUSYAAAAXVBMVEUAAACysrLZ2dkmJiYuLi4xMTFAQEBHR0dJSUlKSkpRUVFSUlJaWlpdXV1jY2N0dHR9fX1/f3+Pj4+SkpKVlZWXl5ehoaGpqamsrKytra2ysrK3t7fCwsLNzc3Z2dky1qB2AAAAA3RSTlMAf3+Sa81KAAAAe0lEQVR42uXNQRKCMBAAQWCCIgGCGEU3sv9/JpXykCLxB8y1D1OdsEaLmqT6p6M6wKn6FuyWaUQL9zdcW2yuLV49dmTUL2S6gcYsr+IbwgdC7MYj/EoqIoZFHF1PL08QkYNO0MG8wMUw5LoOwCQyG+jWTMuS1iXW1SnbAaDLE32SOX+lAAAAAElFTkSuQmCC"/\x3e\x3celement name\x3d"ccButtonOver" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAB0AAAAcCAYAAACdz7SqAAAB8UlEQVR42uWWsWoCQRCGEzUcEhFsQpCzUiwsBBGLoElrp0HbsxI09j6ClaXgW5xYWvgCNhaWFjb6BD7BZmb5HWSXXAw5rnHg43bd3f/fG+f27uE+Qyn1GCa3mMVAnEj8k7jowdwyxKQnwiGSxDNI/Qmsg4YDzbh15/jRwaIM8UJkCRfkbsQFWWhkoOmwh2nqEGnilcgTZaJGvBF1onEjdaypQSMPzbRlzLvBYIl4J9qER/SJATEkvn5hiLl9rG1DqwTtFFId06ZIQ4H4IHwVXvjQLMDDkcJC/svEpwo5oFmGR1JSjD++ptNixGQyUcViUeD+JRaLhapWqzLmeZ46n8+mhAftLKo6cTF1UQB921AEpT2bzdRms5F+q9Vic5lnRB/armmaI+ooBAkI6TvCnYnwaDTitr5ynE4n2YQRA9aGR8o0baAKOXSaRMQOufP1eq2CApqNQNPD4aCY3W4nptS36Ha7emy5XHL/R4JNkd79fq8uVCoVLez7vu5Pp1Pd73Q6qtfrcZuvemy1WskmrzQC0yuFdL1gPB5rERhJez6f80ak32w29QbxHxumdiFZj8z1gu12KwUD9EYwzuYwk43xGsPUfmSswwGTwyLwcJBj8Hg8+mEZklbgMRj9gR/9qy36l3j0nyuRfphF+wl69/ENcVv6gzz3ulwAAAAASUVORK5CYII\x3d"/\x3e\x3celement name\x3d"muteButton" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABsAAAAcCAYAAACQ0cTtAAAA30lEQVR42u2UzQmEMBCFtwNLsARLSAkpwVJSwpZgCQEv6skS5iieLCElzL6FJwxCDlllT3nwkb8hXxLQV01Nzc/Z9739l8gBBRE0j94AiBk3oAceJCCPCM2GauY6zh3AsR/vit5AT8zzBbZCoWdNWypQS0YmQM2tekpDkWzbNs1xqRMQwGraMtk8z5rD1k3TJJgLYF2WZfi2oEw2jqPm4HoHhHMOJNCDAxTLnGHIyALXhRLPmnsfOU+dTpkRJooc+/F1N/bpzLjhITxFAp77i1w3440UxALRzQPU1NTk8gF0y3zyjAvd3AAAAABJRU5ErkJggg\x3d\x3d"/\x3e\x3celement name\x3d"muteButtonOver" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABsAAAAcCAYAAACQ0cTtAAAC2UlEQVR42u3WPUwTYRzHcWmBFnqKBYpAHVSQoEB8QTQaiMSILhgDiiFxUBMSlUETnYiDg9GJmDA44OCgo8bF18EFibq5MEBpeUsDIaVAm6P02qTUb5N/k5P2oNg46ZN88tz1yT2//p9e77lt/1u6Fo/Hc9L5GwEmmJGrY4bpz0JlcoOAPFhRCAU2FMAi46YtBa4LyEM+LBKwHSUoh1OUYaeM5yUDtxpSAAVFKJZJd6MGh9GEY6jHXjigpAQaBskySQWlcMpE+3FQJj+DDtxBN9pxCjUogw25yEkJEWbkw4ZiqaBWJm9GK86jEz0YRKKNok9Cm1El11th/i1QF2TBDuxCtYS0oQv3MIObuI+nGMIwIljAQ1xGI5xQINWlBhXBiTqclgtv4xXCUsUTDOADotAwIsce9OIsqmFHPkzJsORvpKACDVLNNfThJ/TtBb7ADRfCEjQm4/3okHkcyaXU3xAW2FEtFW3U3uAbVDn3IQYvQhjGVTSiHIX6MDMK4EA9LsRisbgR2jt8wg/OtbW1NZU+Qu+nX6T/zth1nEBl8q5cH1aGQ+icmpqKG9GHeb1ebWlpSZ2bm4v4fL7A7OzsIn1GYQ7Uod3lcsWN0N6GQqGhyclJNXG+srLic7vdseXlZa/H4wkRnLKMRr9ZFVr8fv8jLh4MBAKv+fbudWEvCfs8Pz/vUVXVRbXaxMRENBgMjiXGV1dX094g6e7GcqmuFVfQiwcszfvx8fGwhPXjGYEf+SxKNRqhI4nj6elpw1vf6A9dgRo0yUWXcINv/piJvRzfRV80Gh1gBb6yAsMERahugc82/FOnC1RQonvYHkELzoXD4S76i+jGLYKeJ6qlolGCtvC4gv5Jr9tGKrEPB9CAoziJNnRqmtaz2YM40+3FCgV2OHT71x7UStXH0ZTJFpNpqEWqtUnFRShFxWabZ1bvHLpd2yrhijB4LcjyXSSLF56sw4WE/HPtFwoiecfnKRGcAAAAAElFTkSuQmCC"/\x3e\x3celement name\x3d"unmuteButton" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABsAAAAcCAYAAACQ0cTtAAAAk0lEQVR42u2NwQnDMAxFtUFH6AgdISN0hI6UEf4Oxgdvkas9RUZQ/yEBYdChgoZC9eCBLBs/SZLkjxlj3Ol2RehJd6rfDq1UT81eKcwZVCMB9Zw/p7CzfErvXT2ndzB3kAitNfUUQ60V555zLFZKUU/zBscOdo7EFiOcmFLMcQli4y+6Bz4LBx90E3JV8CZJkvwsb8qa9F25tXYIAAAAAElFTkSuQmCC"/\x3e\x3celement name\x3d"unmuteButtonOver" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABsAAAAcCAYAAACQ0cTtAAACOUlEQVR42u3WS2sTURjG8ZqJuTSJTW1T26YqrWmN1jt2ISpWTb1ABS3iRkS84WUndlNQFN34Fdy5d+U36MJVQVroKgnmvgqBZBV3Gf8DTyQMzMggRZC+8CNnJsn75CRnzqRvu/6/Mk1zRw8fwBhbEeSDAT92ih+cU7D8dYiahxFFTPoR1HOG+Fxm7h6kRiE1H8Y49iKJEcQRRRghhQegmTuFKkQMBBDBbkwgjVOY0+Mh7McoEhjSa+OIIawehluYgSB2YQ9SOI0MbuEFfuCizs8ijYOYwRSSCo8g0J2hU9AAkmp0AbfxDJ/RhlV3sYgFZPR4GedwApMKDMNvD+v+RlGM4aga3McKvqO3XuKhxt/wFI+xClOBScTU12dfEEEMIqUZudU7vMKajjewrvGqZjiFOAL2MANhJHAENzqdjumE+ojXeMvxJkyxAh/hEqYxiKBT2AiOY6lQKJhOesNqtdpm93y1WvUUlsAsFrPZrOmEeo/lcrm8Zh1XKpUNxuvWuFgsun6N9t/sAM43Go0PzWbzU6vV+sInztvClvHEGpdKpd8LxArinPMCsa9GjGp287iD51ip1+tfc7ncTzV7gJu4igVc8bL07Rf0GGYwhwyWcI9Zvsnn80XG13EGx3AYafzxonYKjOoNE2pyEmcx3263r2nLmu7ZJ4e9b1ew7fQxhY5jUgEp7FPIAPq9bcTut5cQoohjSOKIIKjGhrjeYryEBhWMnnuZ9+buoaJgUcjW/xeRvu36F/ULlStUoyVtQSYAAAAASUVORK5CYII\x3d"/\x3e\x3celement name\x3d"fullscreenButton" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABgAAAAcCAYAAAB75n/uAAAAbElEQVR42u2R0QnAIAxEu1lWc5/+ZYKs4TTWjwS0qIFrP+/BkYMLOdCLELKn1tpG5TleYF2yyMUzvCAOZDtwgU85PJGE/+NPyuTJG1Uts/9+sI0+y6GCrtunLHKJHbjAZYcd8x28IJTmhJAtD4gEt9ueDIktAAAAAElFTkSuQmCC"/\x3e\x3celement name\x3d"fullscreenButtonOver" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABgAAAAcCAYAAAB75n/uAAACFUlEQVR42t2W324SURCHhS67VCoFbYhRkbQsaCwVSwgUaZP2yia9Mb6MN41vYfpIfYIm5QIegJfA3yTfSU52c1i98KabfGGYmd+cPX+Gw7On+2w2m5JPUfxfC5dhB8pQKooXvjGCiohFFRJ8EVTwVSHGtxOckSuOsCb2xUsDe0/swl42jiZxg2wr/kK0REf0DOzX4hXIzsVbaPODsH4VUSOxL8biwsD+SCEhOx/vo61Rq5zd1JipdhBkn6k4hmk2iKZDjdhtuj9Awnqm4twTPopf4lKM4BLfo0tCk1IjCQ3QFF0xR+QK/BBXYgxX+PycOdpmaAC3RG1xiui7uMWeic8ww3dLzgZNO7tEoU1OxYhpX7Dmd+KDgT0ldk5umt/k/DGtioZ4y/E7EUMx4JQcQR/fkJwemgY1OKbhAd6wnscU+ESRQ+jhOyGniyY4QFlE4rk4sCKIJyzFaLVa/XaNhT0iNiH30LTUiEJ9UGeqg8ViYRv3TVxjj80PY3zXloM9QFvf1gcN3mRiIr3pvX2u1+ufHMMvMDefn2MatI2iPjgSZyYylsvlg77fiK/umGLfWMzlmQbt3/UBQoc7530IxLf3QeT3AYIZbzbE9w5SfGfknGb6IAr1Qez9XL8XXabdxtc0sNvEuuS20MZFd0LsXThNqOOrQg0fcS6cXPHiKzOB2L8yg3GKG4WXfoBSUfz//W15ss8fvEcYMYnLr+AAAAAASUVORK5CYII\x3d"/\x3e\x3celement name\x3d"normalscreenButton" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABgAAAAcCAYAAAB75n/uAAAAbElEQVR42u2Q0QnAMAhEu5kD588JXMNpbIUEpCBpe5+9B4JczF3MQQjpcfeBz+4vxpMe2ULSIF9YjaqWM+hXWRrdA2YZah61Wv2/qGrU6nQkQK6yLmCeCbzFCmk02FxWX/WyYXw1H69mCSEtJ16St50Fqd0HAAAAAElFTkSuQmCC"/\x3e\x3celement name\x3d"normalscreenButtonOver" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABgAAAAcCAYAAAB75n/uAAACDUlEQVR42u2Vy0ojURCGZ9Kmk4A63cYLMhdE28tCECUgxCuzGBDc6AgO7uYizKAP4NKNb6S+g08gSZO8QZ7h+Bd8ScDDIZmsLfhIpc7/V53uPnS/e4uRwjn3vsto2sHiggdrw2iGaT4miiKGEhShBDEU8YSH9Jr3G4yLSZGID+Q9qCXk0rIBhoSaj4kyxlnxUXyBz+ITKKcuDdoEb+9KQrufEHPiXqyLLVETmwDUpEE7h7cYGhBxmQk72xAWR+KY/Bs4akfkG3gSekTebaJYFlWxKLbFDQ2e+P0BvRqabTxVekT+M+gPmBKZ2BWn4tn146czCNa+o83wlkNXUGAxRVx3fvyC11HHk9KjQFtvQIxoSeyIE/Fb/BWX5EK5auQnaJfwxsMMyMSeOKPZVX8IzVUjP0Ob+QP8Y1rhPq6Kg2az6Yw8z12j0XCKf4blVuuum9Y8eCvBY8ritFgTXzudzl273c4VzlBcG93/tmYa05oHb2XQMZ0RK2JfnFujVquVs9M/huVWY+g52hXzDjqmJe7jgqhZI+3wVvkFA04N8gtbI6/hSekRhV4VMS+vee3uAeOeOOSs1w3yQ9Zq0j6aB2/sPwP/ZTeFYUEsc/mZWISM2jKaeTzeyy50FWV2k/LgquQJpNSmySfxeLsPfnAQlzCC1dgAoInxDP9Vg8gAauG1//82I/ZM1DztW4wSL9xQTRdfTNL0AAAAAElFTkSuQmCC"/\x3e\x3c/elements\x3e\x3c/component\x3e\x3ccomponent name\x3d"display"\x3e\x3csettings\x3e\x3csetting name\x3d"bufferinterval" value\x3d"100"/\x3e\x3csetting name\x3d"bufferrotation" value\x3d"45"/\x3e\x3csetting name\x3d"fontcolor" value\x3d"cccccc"/\x3e\x3csetting name\x3d"overcolor" value\x3d"ffffff"/\x3e\x3csetting name\x3d"fontsize" value\x3d"15"/\x3e\x3csetting name\x3d"fontweight" value\x3d"normal"/\x3e\x3c/settings\x3e\x3celements\x3e\x3celement name\x3d"background" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAA8CAIAAAAok0etAAAAJUlEQVR42mNKTU1lunnzJtP///+ZGBgYwDQ6xiVOrhw1zSNRPQBu5Zagca3K1AAAAABJRU5ErkJggg\x3d\x3d"/\x3e\x3celement name\x3d"capLeft" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAoAAAA8CAYAAABfESsNAAAAnElEQVR42u2WvQ2DMBCFv8I1M3gjMoTpMwqjkI1S0RnJEhaiuZcFEuyCBCnyqz+9+9XpHMAwDD0wAp4PciGEXtK0risxRvZ9fw+a2ZhzZp5njuTMzC/LQklOEtu21YGSyqCZ1YHfcazR1Tle6FjVnr+q+vz2XJxjW4p2Utr2tFn/OvT5s5b0BHwJdmZ2Bybg0NmllB5d190kHb5cL8J5WhbWZJeBAAAAAElFTkSuQmCC"/\x3e\x3celement name\x3d"capRight" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAoAAAA8CAYAAABfESsNAAAAmklEQVR42mNKTU39jwffB2J/BiBgunnzJgM2/PjxY4bPnz8r/P//f0NKSoo/E5DBgA1//fqV4enTpyDFDP/+/ZvAxEAAvHnzBqRQAaeJMPzz508wTVAhDBOlEGg1LUxkIAIMtBsH0ERigmf4+XpggodGbhxNFKNFymiRMhrXA1Gk0D+uoQH+gIkIRSCrC5gIeOIBkA74+PHjRgDhswBcaL43lQAAAABJRU5ErkJggg\x3d\x3d"/\x3e\x3celement name\x3d"bufferIcon" src\x3d"data:image/png;base64,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\x3d\x3d"/\x3e\x3celement name\x3d"errorIcon" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACgAAAAoCAYAAACM/rhtAAACL0lEQVR42u2T64nCUBCF7SAlpIQtISVYQkrYElKCJaSElHBL8LfPKD7wyUXxgYrOzkCyHC6b3LgasywOfBDuOTNzcklq73rXfygiqjMxk1YsZ38lXIOyq1F1OI/s5VUZsAlBNOMlaDhvVhXOZ7B80D4ztNeV+VNY9VdUzg3VM/5srM9XhXOMb0zleJXxjTqlB7xer8HtdiPAy/KKhl7pLTXc5XJxGc1QggJNIXgOfs24pQU8nU4hQynn89kFjZD0XDyGFpYS7nA4uMfjkYAQddQEQwtRk1lPD7jb7SKGUvb7vWvoTdCbqIkXNCF6arjNZuNtt1sCAtPDZwp09YMe4AyZ+bSAWmvFUILm4Y7Fo0xderQUep5Rq9XKW6/XBAQ/+fi8AZ5GhicwZj1+i4vFIl4ul5QQZ/lYC8AX5Pi+58nsh8LNZjOfoZT5fO7neAPwZgaUGeIB/F+Fm0wmznQ6jRlKyH1b1uvgred5zbmy6+6Ao9EoGI/HBHh5ftF/6SXZdVe44XDoMJqhBFWgxwO/V8CvwK+Z4rfY7/eDOI4JsC4cDAYO4yVYl8lM3CE7C4XrdrsuQym9Xi+qlVQyW3YArrWp3W6HDKV0Oh1usler1fLTHnku0iOzxQ+EtiUfDAHYYOsl5I6+0Oj9yDNHYNSM84KADqOhNyq65K5fX/wP9tpfznrV9kWu7dbtn1bxgCHj1sorfKmwaEDFUMUo21XrCsNpyVD4yl8GflLvetcfqy+dCCa6ODMoXAAAAABJRU5ErkJggg\x3d\x3d"/\x3e\x3celement name\x3d"playIcon" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACgAAAAoCAYAAACM/rhtAAAArElEQVR42u3YywnAIBBFUTtJaSnFUqzLhVjKZDZmI8HfGx3CPLj7AyKIjoic5pwBDWhAA+oBei5wlxMYClgGh6KBcKgUEAaVBi5DdwGnobuBw9BTwG7oaWATqgX4CdUGrKBagWX3MjCl5DmSKOe8Dowxeo7ABQ5zxGDgC4NdEhCwgmkBfsJOA5uwU8Bu2G7gMGwXcBomDVyGSQFhMDQQDkO+ZuxnwYAGNOAfgQ8LTbXBn1RvGQAAAABJRU5ErkJggg\x3d\x3d"/\x3e\x3celement name\x3d"playIconOver" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACgAAAAoCAYAAACM/rhtAAACJElEQVR42u2YS0sCURTHNc3sTWEPelMQUQQtKnptIojosWgdFLTIFu2qdZ8i6Cv0BVq3KUi3IqgI4hN0rS5v/xtnahh1Gqd7Z0bowA/EWcyPM/ece+9xMcZcTsbVcoJ6gedul4VhSJBLEW0a3LKFdQVVYh7gBT7QQfjoP48ia5egh4S6QT8YJPjvHuAH7bJEGwpq5PrACJgB88QsGAcBet4pQ1RPsI1eyLM0ChbABtgD+2AXrINFMAWGZIg2ajNKQfDsDYA5sA2ewRt4ANfgDByCLbAEpkWL6gl66CXDYBmcgBf2E1HwCG7BBTiWIaon6KXCGANrlK1XVhtx8ATuZYgaEZwAm+ASvLPGkZAh+psgL5BJWn9X4IP9HkJFjQrugCAIMeMhRLQZQV61YdZ86Ikq7amXGr5XK2mFYCPRI1rbi/QOvjt1UTa/Ja0U1IregXNwAFZpZwpoJe0QVLcn3kdvwCntUrOUST+tSVsFlYjQzsQ3ghXquz2URUcIKvFEa3Kaqlv5zMYFi8ViOJlMMhmUSqW/CxYKhXAsFmMiSafTkXK5LOYTixTMZDLxSqUitkhECEIsUa1W5bSZvwiqxOQ1ajOCdcSkbXVBCIYEiQk/LHwdt/L5/IdVYqYOrBB8t0rM1JE/l8u91msXMsRMXZqy2eyLqsFGqY/ZdmmquXZC6jmVSr1R57fv2un4i3tLjD4cPzxqifGb4weYjh0B/0/5m+QT3Dh1BNFdpj4AAAAASUVORK5CYII\x3d"/\x3e\x3celement name\x3d"replayIcon" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACgAAAAoCAYAAACM/rhtAAABxUlEQVR42u2XwY3CMBBF0wElpARKcAkpISWkhJRACS5hS3AJnOHAwoEDB2QOHJCQmP2DcrBGycZ2BtiVMtKTEGLe/NixJYq55prrxUVEBjSgBStgu88NMJ8KVXZBPI2XBxaU7wi2AJbyy7LjVeGWwNP08uzSDlcDPzLUCcZ+X79j5RyofumtgNNeSfnO+QG5SfCYIc+kd3LgQKxzpNzT9cqy2VfJ4BPr70iptXpG42JXWcXH4+EBBbhCqdgl3D5JcL/fDSBBpRWQXT3++N253W4NoABfKBc7xYwmuvl6vbaAApx2QHaKGW108+VysYAC1AOyU8yID3g+n1eAAtQDslPMiA94Op1aQAHqAdkpZsQHPB6PDaAA9UPCTjEj/pAcDgcDSJB1zez3e9Pjr3r8Jkm82+08oADe5lSH6Xqt+N4Jd/oObbdbCyhks9mYREcd9D9DskN6gU0OCFEJSODBIsGxEv22c5Ag7/9KJyTBV0K/AzSCLXKLV6vnieuEftkr+RY7khVyGQyqJ74iEp0/TxBVTGKPedX2aj1UC+jPhuTDBEgvpH7AdUJA/4GAw2GAAy2oNQ7KlEt+DWwXxoBFMddc/6x+ACbEv+zn5grUAAAAAElFTkSuQmCC"/\x3e\x3celement name\x3d"replayIconOver" src\x3d"data:image/png;base64,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"/\x3e\x3c/elements\x3e\x3c/component\x3e\x3ccomponent name\x3d"dock"\x3e\x3csettings\x3e\x3csetting name\x3d"iconalpha" value\x3d"0.75"/\x3e\x3csetting name\x3d"iconalphaactive" value\x3d"0.5"/\x3e\x3csetting name\x3d"iconalphaover" value\x3d"1"/\x3e\x3csetting name\x3d"margin" value\x3d"8"/\x3e\x3c/settings\x3e\x3celements\x3e\x3celement name\x3d"button" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACQAAAAkCAYAAADhAJiYAAAA80lEQVR42u2WQQqDMBBFQ4pQeoVueiN7BtG9R+lR7IlaAllnIZaCxHR+KWLpou7mCxE+Jm7m8b+TiTXy1HVdim5N0yQNoTYYwGKrqiqnaer6vj865x4aQm0wgMXGGC/yYfTeP4dhiBpCbTCAxQrZKYQwppSMpsAAFgAZJiGy90LbITCAhc8hBneWLs2RMegrMgZ3ZodYIuP8qSnbfpmhln66jO5gpOsyhsh4HaI7qfMs29Qsy5H9iyxfYddMe8r7EFWX5cg2FVkeritO6rtsCoILWgEWONRiY4zZy3unoU9tmNLaEMJVFmeRl48HDaE2GMDyAjEWKwKFLBqcAAAAAElFTkSuQmCC"/\x3e\x3celement name\x3d"buttonOver" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACQAAAAkCAYAAADhAJiYAAAA80lEQVR42u2WQQqDMBBFQ4pQeoVueiN7BtG9R+lR7IlaAllnIZaCxHR+KWLpou7mCxE+Jm7m8b+TiTXy1HVdim5N0yQNoTYYwGKrqiqnaer6vj865x4aQm0wgMXGGC/yYfTeP4dhiBpCbTCAxQrZKYQwppSMpsAAFgAZJiGy90LbITCAhc8hBneWLs2RMegrMgZ3ZodYIuP8qSnbfpmhln66jO5gpOsyhsh4HaI7qfMs29Qsy5H9iyxfYddMe8r7EFWX5cg2FVkeritO6rtsCoILWgEWONRiY4zZy3unoU9tmNLaEMJVFmeRl48HDaE2GMDyAjEWKwKFLBqcAAAAAElFTkSuQmCC"/\x3e\x3celement name\x3d"buttonActive" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACQAAAAkCAYAAADhAJiYAAABD0lEQVR42u2XQQ6CMBREm97BeCnjIQjcxLt4KVckrKuphYIC/jEtKRu3fxaSDGlh0ZeZ/2mxRq66rs+iW9M0bw1hbTCAxVZVdVqW5eq9P7Rte9cQ1gYDWOw8zxd5ELque4QQeg1hbTCAxQrZ0Tn3XNd11BQYwAKgkUmI7DsQyklTYAALn0Nyi4lyVBZciltkDNpFpu3QrqizZcoiLeqi7dUj2xxKFa6q/C3idIiyywgiI3ZIBi9th8BQdhmFdl3GuJepn4fy8eMf2c/IEtBEENnEu9uz1BBvlzFGRvHXwRmZUMU0icpCUUfL4E7pEhwayvOIllLbD3DIY2KMUSvsvDZYrHPuLYM+v9BQgunB8gFJekgEq5c0PwAAAABJRU5ErkJggg\x3d\x3d"/\x3e\x3celement name\x3d"divider" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAQAAAAECAYAAACp8Z5+AAAAEklEQVR42mP4//8/AzJmIF0AAHImL9Fd8LZHAAAAAElFTkSuQmCC"/\x3e\x3c/elements\x3e\x3c/component\x3e\x3ccomponent name\x3d"playlist"\x3e\x3csettings\x3e\x3csetting name\x3d"activecolor" value\x3d"bfbfbf"/\x3e\x3csetting name\x3d"backgroundcolor" value\x3d"262626"/\x3e\x3csetting name\x3d"fontcolor" value\x3d"999999"/\x3e\x3csetting name\x3d"fontsize" value\x3d"11"/\x3e\x3csetting name\x3d"fontweight" value\x3d"normal"/\x3e\x3csetting name\x3d"overcolor" value\x3d"cccccc"/\x3e\x3csetting name\x3d"titlecolor" value\x3d"cccccc"/\x3e\x3csetting name\x3d"titleactivecolor" value\x3d"ffffff"/\x3e\x3csetting name\x3d"titleovercolor" value\x3d"ffffff"/\x3e\x3csetting name\x3d"titlesize" value\x3d"13"/\x3e\x3csetting name\x3d"titleweight" value\x3d"normal"/\x3e\x3c/settings\x3e\x3celements\x3e\x3celement name\x3d"divider" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAFAAAAACCAIAAABANcwGAAAAKElEQVR42mNhGPqAmZmZiYkJQsIZuLgsvr6+Q9q3/2Dg79+/yAxcXADiODDtLQ68BAAAAABJRU5ErkJggg\x3d\x3d"/\x3e\x3celement name\x3d"item" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAFAAAABQCAYAAACOEfKtAAAAMElEQVR42u3BMQEAAADCoPVPbQ0PoAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAIAXA2RQAAEB5C4HAAAAAElFTkSuQmCC"/\x3e\x3celement name\x3d"itemActive" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAFAAAABQCAYAAACOEfKtAAAAkklEQVR42u3QsQkAIAxFQQsHy/4LqYWohYW9IAj34ENIeTkiRvq7vlb3ynHXB/+Wk64CCBAgQIACCBAgQAEECBCgAAIECFAAAQIEKIAAAQIUQIAAAQogQIAABRAgQIACCBAgQAEECBAgQAEECBCgAAIECFAAAQIEKIAAAQIUQIAAAQogQIAABRAgQIACCBAgQJ1NmcoiAdM9H4IAAAAASUVORK5CYII\x3d"/\x3e\x3celement name\x3d"itemImage" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAADYAAAA2CAAAAACpLjUBAAAAeklEQVR42mPiJQswMXCSARiYGFjIAEBtZAEmRnJ0MZJrG321jfpt1G+DzW8jMUj2lzMwlO8n2W87PMrLPXaQ7LfOHR4eOzpJ99vLe/deku63eItDhyziSfab5fGFC49bkuy3jIUMDAszRtPkaDYd9duo34aT3/6TARgA1wJNszqw3XsAAAAASUVORK5CYII\x3d"/\x3e\x3celement name\x3d"sliderCapBottom" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABoAAAAKCAYAAACqnE5VAAAAEklEQVQ4EWNgGAWjYBSMAnQAAAQaAAFh133DAAAAAElFTkSuQmCC"/\x3e\x3celement name\x3d"sliderCapTop" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABoAAAAKCAYAAACqnE5VAAAAEklEQVQ4EWNgGAWjYBSMAnQAAAQaAAFh133DAAAAAElFTkSuQmCC"/\x3e\x3celement name\x3d"sliderRail" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABoAAAABCAYAAADAW76WAAAAEElEQVR42mNiIA78J4AJAgCXsgf7Men2/QAAAABJRU5ErkJggg\x3d\x3d"/\x3e\x3celement name\x3d"sliderRailCapBottom" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABoAAAAECAYAAACQli8lAAAAJklEQVR42mNgIA78J4CpBu7jseQ+NS3yx2ORPwOVgT+az+6TYgkAKMIaoyp3CGoAAAAASUVORK5CYII\x3d"/\x3e\x3celement name\x3d"sliderRailCapTop" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABoAAAAECAYAAACQli8lAAAALElEQVR42mNgIB74A/F9IP4PxfehYlQF/kgWoGOqWnYfj0X3qWnRfwKYIAAAPu0ao3yGmCgAAAAASUVORK5CYII\x3d"/\x3e\x3celement name\x3d"sliderThumb" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABoAAAABCAYAAADAW76WAAAAMElEQVR42mP+//8/Q0NDA16sqqr6Pycnp6G0tLShqqqqoba2tgEEGhsbG6CgkZAZAEhcK/uBtK2eAAAAAElFTkSuQmCC"/\x3e\x3celement name\x3d"sliderThumbCapBottom" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABoAAAAECAYAAACQli8lAAAAUElEQVR42q3NoREAIQwEwHSYJjOo1IBIDfEx+EgEDMfLVwyCbWDphoig1gp3R2sNmYneO+acWGuBXimlxCEKekVV+RAxvWRm/EXxi2KMcZ1sxLJpnEUZrv0AAAAASUVORK5CYII\x3d"/\x3e\x3celement name\x3d"sliderThumbCapTop" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABoAAAAECAYAAACQli8lAAAAUklEQVR42q3NoREAIQwFUTpMk0wUNSBSAz4mPhIBk8/JUwwiW8C+8pqI0BhDzQzujjmnrrWoZNZao947Pgg/CHtvREQexsx6gTQNqrXiAuHlcQDl9mmceNYnwwAAAABJRU5ErkJggg\x3d\x3d"/\x3e\x3c/elements\x3e\x3c/component\x3e\x3ccomponent name\x3d"tooltip"\x3e\x3csettings\x3e\x3csetting name\x3d"fontcase" value\x3d"normal"/\x3e\x3csetting name\x3d"fontcolor" value\x3d"cccccc"/\x3e\x3csetting name\x3d"fontsize" value\x3d"12"/\x3e\x3csetting name\x3d"fontweight" value\x3d"normal"/\x3e\x3csetting name\x3d"activecolor" value\x3d"cccccc"/\x3e\x3csetting name\x3d"overcolor" value\x3d"ffffff"/\x3e\x3c/settings\x3e\x3celements\x3e\x3celement name\x3d"arrow" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAoAAAAICAYAAADA+m62AAAASklEQVR42p3KQQ2AMAAEwXOAi/lWSqUgpZIqASmVAN+GNECYZH8bHDhfOoLyYSxJEuwP054Z+mLqucOGMU0DW1ZQp7HmCRpa/roABHU6b1RN/woAAAAASUVORK5CYII\x3d"/\x3e\x3celement name\x3d"background" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAQAAAAECAIAAAAmkwkpAAAADklEQVR42mNQQwIMxHEAuXQHISaBGr0AAAAASUVORK5CYII\x3d"/\x3e\x3celement name\x3d"capTop" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAQAAAAECAIAAAAmkwkpAAAADklEQVR42mNQQwIMxHEAuXQHISaBGr0AAAAASUVORK5CYII\x3d"/\x3e\x3celement name\x3d"capBottom" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAQAAAAECAIAAAAmkwkpAAAADklEQVR42mNQQwIMxHEAuXQHISaBGr0AAAAASUVORK5CYII\x3d"/\x3e\x3celement name\x3d"capLeft" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAQAAAAECAIAAAAmkwkpAAAADklEQVR42mNQQwIMxHEAuXQHISaBGr0AAAAASUVORK5CYII\x3d"/\x3e\x3celement name\x3d"capRight" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAQAAAAECAIAAAAmkwkpAAAADklEQVR42mNQQwIMxHEAuXQHISaBGr0AAAAASUVORK5CYII\x3d"/\x3e\x3celement name\x3d"capTopLeft" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAQAAAAECAYAAACp8Z5+AAAAIElEQVR42mNgAAI1NTV/IL4PxP9hnP8wzACTQRb4j4wBSrYUAF5mO7QAAAAASUVORK5CYII\x3d"/\x3e\x3celement name\x3d"capTopRight" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAQAAAAECAYAAACp8Z5+AAAAH0lEQVR42mNQU1P7D8T3gdifAQSgAjDsjy5wH13gPwBoAhQA/dBvkQAAAABJRU5ErkJggg\x3d\x3d"/\x3e\x3celement name\x3d"capBottomLeft" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAQAAAAECAYAAACp8Z5+AAAAHUlEQVR42mNQU1P7j4wZgMR9dAF/FAEQgAqCVQIAxzkUAKo9yiMAAAAASUVORK5CYII\x3d"/\x3e\x3celement name\x3d"capBottomRight" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAQAAAAECAYAAACp8Z5+AAAAHElEQVR42mNQU1P7j4wZ0ATuowv4wwTugzlAAADkhRQAhODqdgAAAABJRU5ErkJggg\x3d\x3d"/\x3e\x3celement name\x3d"menuTopHD" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAFAAAAAYCAYAAABtGnqsAAABKUlEQVR42u2WYQ2DMBSEcYCESuAHAioBCZOAhOFgEiahEpCAhEpAQtcu1+TSwSDbfrDtvuQFWtpHe7lXqCohhBAPDMPQxBhjhBhzjDM9O3MbfWmspfYVc82zeegPlCMUkfpc8f4aa2qOKl5eYI+2iTHlTewU0Mc4bQnPAq6No/UYtN1SniMJmDbuFhzp9wgYr11yIO6ndwWknPd3cM6jCrhValsCJod0VMrduwJS3nDY0qWF9tlB1Gf2OBDlVp5j7kMCpvzjN3xATD6kIYjjcwclPi6dUXhWiu/x7D8EJJFmOMvDSX3hOI/rTOJOuWRp7CWLQnPGLMZPCkjOsuTEtLG6+LDY4lfFruRp4ELLsTQH48xaHv1kCiGEECLStm1QvB5ykBBCiJe5AX69621Fd8YvAAAAAElFTkSuQmCC"/\x3e\x3celement name\x3d"menuTopCC" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAGAAAAAYCAYAAAAF6fiUAAABjklEQVR42u1X3c2DMAzsBhmBEXhggIzACIzACGUDRmCEjsAIGSEjMAIfkS7oegr0oQ/9IvkkC2HH+fHZDjweBoPBYDAIpmlqD1kP2Q/ZDhnEPsA2kM5Dt5PfWNBnSfpnEpojvUfYwyE92ZJulPXWi/3ONQff5eDhvcG7pzGvFJwcAA2I+DUcRFnrJABkhTwe8yX/lgiIYl9pP0/af9CkqYmAlN0v0TV08HTASAdvSgRAF4S4OwJiDjbZEykLVwAFnQlYMJfT/dZIwFtbKNjHXOIga6aAxOyPoATxvSNgL6zFQd7xXLEu2xzmCpCTjBoJOLNOKqClrH7r9RcEjBqEDwRsmrVcjURAbm09V4O00EXPUBMBDfde7rGwRRm/aEbezH1HwMxBo17eqy9d1iu1r/6ujdZ4D2wo94inQ5BmGdvD/i0BDkTn9d6+Zgq+Qb6CNmpBm94ntX4NeamEttRbMc59OjS3iqvLEjpfaF/+qi3KPrz9SBgMBoPBYDD8a3Rdt5v8TiwDDQaDwWD4Ef4AO4h4lB2vwSEAAAAASUVORK5CYII\x3d"/\x3e\x3celement name\x3d"menuOption" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABQAAAAUCAYAAACNiR0NAAAAuElEQVR42u2SQQqGIBCF/wOU1UYUMjAiQdSTeI4O2DnmUL9PatVq3AUNPBhEPt6bmd9XL6u+77uiXHRAV9+1wvais4iEEFXor7e9xdkJiJSSjDG0LAsppWgYhgplOb2iVdi2bRRCqHLOkdb6dpo5wAPu4AyglFJVjJGstTSOI+EPF4iYD+C6rjRNExuIyJgZYgJU5b2neZ7vBWX2UrAAzAwx4QwwuLuX0no2mBlAcMY4G85hf/Wu+gNm+kvWRCvtuQAAAABJRU5ErkJggg\x3d\x3d"/\x3e\x3celement name\x3d"menuOptionOver" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABQAAAAUCAYAAACNiR0NAAABfklEQVR42r2VTWqDUBSFG6v5KcVJsWTWaUZdRLuNbsNxt5CZ4/xsIJhAkGQJ3UBCcCA6UhBJQDDk9h04giREKQkVPpD37j3cc+/z+dD0iEirSn10s4hGHokG/iReEdIVbUVH0SMdrumlcKMYKzEUTwpT8aKwAN9N7hmMbdWKsYJnCrwpBop3MuCaxZh2KXrNpsHAPpK32+2H4zjfw+HQAXjHGoX7jDUu7FNQpxULCa7rftm2/TMajeLZbJaB8XgcYw17FLWYo58LaizfhCVVxScSl8vlYbPZSBiGEkWR7HY78TzvgD3E0L7JXO3cbpdNH8AaqoFYmqZSFIUcj0fZ7/fi+75MJpMYMYhlTre0XR1GT/GK5qNfsIjKIFY+p9NJ4jiW1Wp1QAximdODRqMgbKKyqmCSJLJYLLJrgrWW0TPYhBDI81yCIJDpdHrVcu1QMAD0DDZRGcTW63XdUJqPDSqdz+cZ+oZhNB6b+x/s+396t18Od72+/vuCvf0X8At7J48fIgP61QAAAABJRU5ErkJggg\x3d\x3d"/\x3e\x3celement name\x3d"menuOptionActive" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABQAAAAUCAYAAACNiR0NAAABfklEQVR42r2VTWqDUBSFG6v5KcVJsWTWaUZdRLuNbsNxt5CZ4/xsIJhAkGQJ3UBCcCA6UhBJQDDk9h04giREKQkVPpD37j3cc+/z+dD0iEirSn10s4hGHokG/iReEdIVbUVH0SMdrumlcKMYKzEUTwpT8aKwAN9N7hmMbdWKsYJnCrwpBop3MuCaxZh2KXrNpsHAPpK32+2H4zjfw+HQAXjHGoX7jDUu7FNQpxULCa7rftm2/TMajeLZbJaB8XgcYw17FLWYo58LaizfhCVVxScSl8vlYbPZSBiGEkWR7HY78TzvgD3E0L7JXO3cbpdNH8AaqoFYmqZSFIUcj0fZ7/fi+75MJpMYMYhlTre0XR1GT/GK5qNfsIjKIFY+p9NJ4jiW1Wp1QAximdODRqMgbKKyqmCSJLJYLLJrgrWW0TPYhBDI81yCIJDpdHrVcu1QMAD0DDZRGcTW63XdUJqPDSqdz+cZ+oZhNB6b+x/s+396t18Od72+/vuCvf0X8At7J48fIgP61QAAAABJRU5ErkJggg\x3d\x3d"/\x3e\x3celement name\x3d"volumeCapTop" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABQAAAAGCAYAAADDl76dAAAAFUlEQVR42mP4//8/AzUxw6iBg89AACt1ZqjY29nMAAAAAElFTkSuQmCC"/\x3e\x3celement name\x3d"volumeCapBottom" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABQAAAAGCAYAAADDl76dAAAAFUlEQVR42mP4//8/AzUxw6iBg89AACt1ZqjY29nMAAAAAElFTkSuQmCC"/\x3e\x3celement name\x3d"volumeRail" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABQAAAA8CAYAAABmdppWAAAAPklEQVR42u3MoREAIAwDQDpI95+xVwG2AjziY3IR+ViPZOaeu7tXVc2O2y+AQCAQCAQCgUAgEAgEAoHAP8ADVGLAaqN7TdUAAAAASUVORK5CYII\x3d"/\x3e\x3celement name\x3d"volumeRailCapBottom" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABQAAAAECAYAAACOXx+WAAAAXklEQVR42pXOMQrAIAyFYUGSIeqQuLh4Ju8/eZRXIhQ6WMHhhxDIRwKAsKv3jm+tNagqcs4gIvzdhQM4d2BKCcw8r8FSyqi1Lsgzs/WdgzHGcQ2+qIhMhzyffXe6eQBmfbZnUQ+tqAAAAABJRU5ErkJggg\x3d\x3d"/\x3e\x3celement name\x3d"volumeRailCapTop" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABQAAAAECAYAAACOXx+WAAAAX0lEQVR42p2OsQrAIAxEhRAHoxB1cfGb/P/JTzkboVsttMODcOEe5wC4EymlEUKYMUYYdlv21jk+VHXUWtFa25RStlREQETjs7D3Pi9wY9Kc8xZ67+cfIZ6EtpKZceot+LS2cEn/XGYAAAAASUVORK5CYII\x3d"/\x3e\x3celement name\x3d"volumeProgress" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABQAAAA8CAYAAABmdppWAAAASUlEQVR42u3MQQ0AUQjE0CFYgARQjGvWwBewh/beZ3enV7t77q7MVFWpuzUzigiZmSTZ6zNAQEBAQEBAQEBAQEBAQEBAQMB/gB8nJqOYNsUfIAAAAABJRU5ErkJggg\x3d\x3d"/\x3e\x3celement name\x3d"volumeProgressCapBottom" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABQAAAAECAYAAACOXx+WAAAAVUlEQVR42pXMwQkAIQxE0XSYshQtImXYhh3kKFiD+L3s3iTgwBz/E0BuTylRSsHMaK3Re2fOyd6bb9dOAtAD0J/BnLMGoD6DgNRa1cz8B8cYvtbSqDn4F/TaDHcq1wAAAABJRU5ErkJggg\x3d\x3d"/\x3e\x3celement name\x3d"volumeProgressCapTop" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABQAAAAECAYAAACOXx+WAAAAVElEQVR42mP5//8/Ay7Q09PjLyIiMkFCQkJBUlKSQVxc/IGoqGgBMzPzRlx6WHBJdHZ2+jMxMW1AFgMapAAVCwDijSQZCHT5BAbcYALJBgKBAjlyAHZIEpxZZYn/AAAAAElFTkSuQmCC"/\x3e\x3celement name\x3d"volumeThumb" src\x3d"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABQAAAAMCAYAAABiDJ37AAAAnklEQVR42mP4//8/AxbMBMTsQMwHxMJALALFwlAxdqgaDL24DOMGYoVly5ZFVldXz6ysrFwOwiA2SAwkB1XDRMhARqjtigcPHsw/d+7c9Z9A8B8KQGyQGEgOpAaqlpGQgSAv2Vy7du38fxwAKmcDVYvXQCZoOHkjuwwdQOW8oWqZCBkICvyA/4RBAFQt/Q2kqpepHilUTzZUT9gUZz0ACDf945eBHBQAAAAASUVORK5CYII\x3d"/\x3e\x3c/elements\x3e\x3c/component\x3e\x3c/components\x3e\x3c/skin\x3e';this.xml=
e.utils.parseXML(this.text);return this}})(jwplayer);
(function(e){var f=jwplayer.utils,c=jwplayer.events,b=c.state,a=f.css,d=document,j=".jwpreview",n=!0,h=!1;e.display=function(g,t){function k(){switch(w.jwGetState()){case b.PLAYING:case b.BUFFERING:w.jwPause();break;default:w.jwPlay()}X.sendEvent(c.JWPLAYER_DISPLAY_CLICK)}function s(a,b){R.showicons&&(a||b?(K.setRotation("buffer"==a?parseInt(R.bufferrotation):0,parseInt(R.bufferinterval)),K.setIcon(a),K.setText(b)):K.hide())}function l(b){B!=b?(B&&r(j,h),(B=b)?(b=new Image,b.addEventListener("load",
u,h),b.src=B):(a("#"+p.id+" "+j,{"background-image":void 0}),r(j,h),D=C=0)):B&&r(j,n);y(w.jwGetState())}function q(a){clearTimeout(N);N=setTimeout(function(){y(a.newstate)},100)}function y(a){K&&K.setRotation(0);switch(a){case b.IDLE:!J&&!M&&(B&&!G&&r(j,n),s("play",v?v.title:""));break;case b.BUFFERING:J=h;z.error&&z.error.setText();M=h;s("buffer");break;case b.PLAYING:s();break;case b.PAUSED:s("play")}}function u(){D=this.width;C=this.height;y(w.jwGetState());A();B&&a("#"+p.id+" "+j,{"background-image":"url("+
B+")"})}function m(a){J=n;s("error",a.message)}function A(){0<p.clientWidth*p.clientHeight&&f.stretch(w.jwGetStretching(),x,p.clientWidth,p.clientHeight,D,C)}function r(b,c){f.exists(H[b])||(H[b]=!1);H[b]!=c&&(H[b]=c,a("#"+p.id+" "+b,{opacity:c?1:0,visibility:c?"visible":"hidden"}))}var w=g,p,x,v,B,D,C,G=h,z={},J=h,M=h,H={},K,R=f.extend({showicons:n,bufferrotation:45,bufferinterval:100,fontcolor:"#ccc",overcolor:"#fff",fontsize:15,fontweight:""},g.skin.getComponentSettings("display"),t),X=new c.eventdispatcher;
f.extend(this,X);this.clickHandler=k;var N;this.hidePreview=function(a){G=a;r(j,!a)};this.element=function(){return p};this.redraw=A;this.show=function(){K&&w.jwGetState()!=b.PLAYING&&K.show()};this.hide=function(){K&&K.hide()};this.setAlternateClickHandler=function(){};this.revertAlternateClickHandler=function(){};p=d.createElement("div");p.id=w.id+"_display";p.className="jwdisplay";x=d.createElement("div");x.className="jwpreview jw"+w.jwGetStretching();p.appendChild(x);w.jwAddEventListener(c.JWPLAYER_PLAYER_STATE,
q);w.jwAddEventListener(c.JWPLAYER_PLAYLIST_ITEM,function(){J=h;z.error&&z.error.setText();v=w.jwGetPlaylist()[w.jwGetPlaylistIndex()];l(v?v.image:"")});w.jwAddEventListener(c.JWPLAYER_PLAYLIST_COMPLETE,function(){M=n;s("replay");var a=w.jwGetPlaylist()[0];l(a.image)});w.jwAddEventListener(c.JWPLAYER_MEDIA_ERROR,m);w.jwAddEventListener(c.JWPLAYER_ERROR,m);p.addEventListener("click",k,h);var Y={font:R.fontweight+" "+R.fontsize+"px/"+(parseInt(R.fontsize)+3)+"px Arial,Helvetica,sans-serif",color:R.fontcolor};
K=new e.displayicon(p.id+"_button",w,Y,{color:R.overcolor});p.appendChild(K.element());q({newstate:b.IDLE})};a(".jwdisplay",{position:"absolute",cursor:"pointer",width:"100%",height:"100%",overflow:"hidden"});a(".jwdisplay .jwpreview",{position:"absolute",width:"100%",height:"100%",background:"no-repeat center",overflow:"hidden",opacity:0});a(".jwdisplay, .jwdisplay *",{"-webkit-transition":"opacity .25s, background-image .25s, color .25s","-moz-transition":"opacity .25s, background-image .25s, color .25s",
"-o-transition":"opacity .25s, background-image .25s, color .25s"})})(jwplayer.html5);
(function(e){var f=jwplayer.utils,c=f.css,b=void 0,a=document,d="none",j="100%";e.displayicon=function(e,h,g,t){function k(a,b){return"#"+r+(b?":hover":"")+" "+(a?a:"")}function s(b,c,d,e){var f=a.createElement("div");f.className=b;c&&c.appendChild(f);l(b,"."+b,d,e);return f}function l(a,b,d,e){var g=q(a);"replayIcon"==a&&!g.src&&(g=q("playIcon"));d=f.extend({},d);0<a.indexOf("Icon")&&(G=g.width);g.src&&(d["background-image"]="url("+g.src+")",d.width=g.width);c(k(b),d);e=f.extend({},e);g.overSrc&&
(e["background-image"]="url("+g.overSrc+")");C=g;c("#"+m.id+" .jwdisplay:hover "+(b?b:k()),e)}function q(a){var b=A.getSkinElement("display",a);a=A.getSkinElement("display",a+"Over");return b?(b.overSrc=a&&a.src?a.src:"",b):{src:"",overSrc:"",width:0,height:0}}function y(){var a=v||0==G,e="px "+j,g;c(k(".jwtext"),{display:B.innerHTML&&a?b:d});setTimeout(function(){g=Math.max(C.width,f.bounds(w).width-x.width-p.width);(f.isFF()||f.isIE())&&g++;f.isChrome()&&1==w.parentNode.clientWidth%2&&g++;c(k(),
{"background-size":[p.width+e,g+e,x.width+e].join()},!0)},0)}function u(){M=(M+J)%360;f.rotate(D,M)}var m=h,A=m.skin,r=e,w,p,x,v,B,D,C,G=0;this.element=function(){return w};this.setText=function(b){var c=B.style;B.innerHTML=b?b.replace(":",":\x3cbr\x3e"):"";c.height="0";c.display="block";if(b)for(;2<Math.floor(B.scrollHeight/a.defaultView.getComputedStyle(B,null).lineHeight.replace("px",""));)B.innerHTML=B.innerHTML.replace(/(.*) .*$/,"$1...");c.height="";c.display="";y()};this.setIcon=function(a){var b=
s("icon");b.id=w.id+"_"+a;l(a+"Icon","#"+b.id);w.replaceChild(b,D);D=b};var z,J=0,M;this.setRotation=function(a,b){clearInterval(z);M=0;J=a;0==a?u():z=setInterval(u,b)};h=this.hide=function(){w.style.opacity=0};this.show=function(){w.style.opacity=1};w=s("jwdisplayIcon");w.id=r;e=q("background");p=q("capLeft");x=q("capRight");v=0<p.width*x.width;var H={"background-image":"url("+p.src+"), url("+e.src+"), url("+x.src+")","background-position":"left,center,right","background-repeat":"no-repeat",padding:"0 "+
x.width+"px 0 "+p.width+"px",height:e.height,"margin-top":e.height/-2};c(k(),H);e.overSrc&&(H["background-image"]="url("+p.overSrc+"), url("+e.overSrc+"), url("+x.overSrc+")");c("#"+m.id+" .jwdisplay:hover "+k(),H);B=s("jwtext",w,g,t);D=s("icon",w);h();y()};c(".jwdisplayIcon",{display:"table",cursor:"pointer",position:"relative","margin-left":"auto","margin-right":"auto",top:"50%"},!0);c(".jwdisplayIcon div",{position:"relative",display:"table-cell","vertical-align":"middle","background-repeat":"no-repeat",
"background-position":"center"});c(".jwdisplayIcon div",{"vertical-align":"middle"},!0);c(".jwdisplayIcon .jwtext",{color:"#fff",padding:"0 1px","max-width":"300px","overflow-y":"hidden","text-align":"center","-webkit-user-select":d,"-moz-user-select":d,"-ms-user-select":d,"user-select":d})})(jwplayer.html5);
(function(e){var f=jwplayer.utils,c=f.css,b=f.bounds,a=".jwdockbuttons",d=document;e.dock=function(j,n){function h(a,b){var d=k(a);c(g("."+a),{width:d.width,background:d.src});return t("div",a,b)}function g(a){return"#"+q+" "+(a?a:"")}function t(a,b,c){a=d.createElement(a);b&&(a.className=b);c&&c.appendChild(a);return a}function k(a){return(a=y.getSkinElement("dock",a))?a:{width:0,height:0,src:""}}function s(){c(a+" .capLeft, "+a+" .capRight",{display:u?"block":"none"})}var l=f.extend({},{iconalpha:0.75,
iconalphaactive:0.5,iconalphaover:1,margin:8},n),q=j.id+"_dock",y=j.skin,u=0,m={},A={},r,w,p=this;p.redraw=function(){b(r)};p.element=function(){return r};p.offset=function(a){c(g(),{"margin-left":a})};p.hide=function(){p.visible=!1;r.style.opacity=0;r.style.visibility="hidden"};p.show=function(){p.visible=!0;r.style.opacity=1;r.style.visibility="visible"};p.addButton=function(a,d,f,g){if(!m[g]){var k=t("div","divider",w),h=t("button",null,w),j=t("div",null,h);j.id=q+"_"+g;j.innerHTML="\x26nbsp;";
c("#"+j.id,{"background-image":a});"string"==typeof f&&(f=new Function(f));h.addEventListener("click",f);m[g]={element:h,label:d,divider:k,icon:j};if(d){var p=new e.overlay(j.id+"_tooltip",y,!0);a=t("div");a.id=p.id+"_label";a.innerHTML=d;c("#"+a.id,{padding:3});p.setContents(a);var l;h.addEventListener("mouseover",function(){clearTimeout(l);var a=A[g],d,e;d=b(m[g].icon);a.offsetX(0);e=b(r);c("#"+a.element().id,{left:d.left-e.left+d.width/2});d=b(a.element());e.left>d.left&&a.offsetX(e.left-d.left+
8);p.show();for(var f in A)f!=g&&A[f].hide()},!1);h.addEventListener("mouseout",function(){l=setTimeout(p.hide,100)},!1);r.appendChild(p.element());A[g]=p}u++;s()}};p.removeButton=function(a){m[a]&&(w.removeChild(m[a].element),w.removeChild(m[a].divider),delete m[a],u--,s())};p.numButtons=function(){return u};p.visible=!1;r=t("div","jwdock");w=t("div","jwdockbuttons");r.appendChild(w);r.id=q;var x=k("button"),v=k("buttonOver"),B=k("buttonActive");x&&(c(g(),{height:x.height,padding:l.margin}),c(a,
{height:x.height}),c(g("button"),{width:x.width,cursor:"pointer",border:"none",background:x.src}),v.src&&c(g("button:hover"),{background:v.src}),B.src&&c(g("button:active"),{background:B.src}),c(g("button\x3ediv"),{opacity:l.iconalpha}),c(g("button:hover\x3ediv"),{opacity:l.iconalphaover}),c(g("button:active\x3ediv"),{opacity:l.iconalphaactive}),c(g(".jwoverlay"),{top:l.margin+x.height}),h("capLeft",w),h("capRight",w),h("divider"));setTimeout(function(){b(r)})};c(".jwdock",{position:"absolute",width:"100%",
opacity:0});c(".jwdock \x3e *",{height:"100%","float":"left"});c(".jwdock \x3e .jwoverlay",{height:"auto","float":"none","z-index":99});c(a,{position:"absolute"});c(a+" button",{position:"relative"});c(a+" \x3e *",{height:"100%","float":"left"});c(a+" .divider",{display:"none"});c(a+" button ~ .divider",{display:"block"});c(a+" .capLeft, "+a+" .capRight",{display:"none"});c(a+" .capRight",{"float":"right"});c(a+" button \x3e div",{left:0,right:0,top:0,bottom:0,margin:5,position:"absolute","background-position":"center",
"background-repeat":"no-repeat"});f.transitionStyle(".jwdock","background .15s, opacity .15s");f.transitionStyle(".jwdock .jwoverlay","opacity .15s");f.transitionStyle(a+" button div","opacity .15s")})(jwplayer.html5);
(function(e){var f=jwplayer,c=f.utils,b=f.events,a=b.state,d=f.playlist;e.instream=function(f,n,h,g){function t(a){C&&C&&G.sendEvent(a.type,a)}function k(){C&&v.play()}function s(){C&&setTimeout(function(){M.jwInstreamDestroy(!0)},10)}function l(a){a.metadata.width&&a.metadata.height&&A.resizeMedia()}function q(){B&&B.redraw();D&&D.redraw()}var y={controlbarseekable:"always",controlbarpausable:!0,controlbarstoppable:!0,playlistclickable:!0},u,m,A=h,r,w,p,x,v,B,D,C=!1,G,z,J,M=this;this.load=function(h,
K){g.setMute(n.mute);g.setVolume(n.volume);C=!0;m=c.extend(y,K);u=new d.item(h);v||(v=new e.video(n.getVideo().getTag()),v.addGlobalListener(t),v.addEventListener(b.JWPLAYER_MEDIA_META,l),v.addEventListener(b.JWPLAYER_MEDIA_COMPLETE,s),v.addEventListener(b.JWPLAYER_MEDIA_BUFFER_FULL,k));v.attachMedia();z=document.createElement("div");z.id=M.id+"_instream_container";g.detachMedia();r=v.getTag();x=n.playlist[n.item];p=f.jwGetState();(p==a.BUFFERING||p==a.PLAYING)&&r.pause();w=r.currentTime;D=new e.display(M);
D.setAlternateClickHandler(function(c){J.state==a.PAUSED?M.jwInstreamPlay():C&&G.sendEvent(b.JWPLAYER_INSTREAM_CLICK,c)});z.appendChild(D.element());c.isMobile()||(B=new e.controlbar(M),z.appendChild(B.element()));A.setupInstream(z,r);q();v.load(u)};this.jwInstreamDestroy=function(c){if(C){C=!1;p!=a.IDLE?v.load(x,!1):v.stop(!0);v.detachMedia();A.destroyInstream();if(B)try{B.element().parentNode.removeChild(B.getDisplayElement())}catch(d){}G.sendEvent(b.JWPLAYER_INSTREAM_DESTROYED,{reason:c?"complete":
"destroyed"});g.attachMedia();if(p==a.BUFFERING||p==a.PLAYING)r.play(),n.playlist[n.item]==x&&n.getVideo().seek(w)}};this.jwInstreamAddEventListener=function(a,b){G.addEventListener(a,b)};this.jwInstreamRemoveEventListener=function(a,b){G.removeEventListener(a,b)};this.jwInstreamPlay=function(){C&&v.play(!0)};this.jwInstreamPause=function(){C&&v.pause(!0)};this.jwInstreamSeek=function(a){C&&v.seek(a)};this.jwInstreamGetState=function(){return!C?void 0:J.state};this.jwInstreamGetPosition=function(){return!C?
void 0:J.position};this.jwInstreamGetDuration=function(){return!C?void 0:J.duration};this.playlistClickable=function(){return!C||"true"==m.playlistclickable.toString().toLowerCase()};this.jwPlay=function(){"true"==m.controlbarpausable.toString().toLowerCase()&&this.jwInstreamPlay()};this.jwPause=function(){"true"==m.controlbarpausable.toString().toLowerCase()&&this.jwInstreamPause()};this.jwStop=function(){"true"==m.controlbarstoppable.toString().toLowerCase()&&(this.jwInstreamDestroy(),f.jwStop())};
this.jwSeek=function(a){switch(m.controlbarseekable.toLowerCase()){case "always":this.jwInstreamSeek(a);break;case "backwards":J.position>a&&this.jwInstreamSeek(a)}};this.jwGetPosition=function(){};this.jwGetDuration=function(){};this.jwGetWidth=f.jwGetWidth;this.jwGetHeight=f.jwGetHeight;this.jwGetFullscreen=f.jwGetFullscreen;this.jwSetFullscreen=f.jwSetFullscreen;this.jwGetVolume=function(){return n.volume};this.jwSetVolume=function(a){v.volume(a);f.jwSetVolume(a)};this.jwGetMute=function(){return n.mute};
this.jwSetMute=function(a){v.mute(a);f.jwSetMute(a)};this.jwGetState=function(){return J.state};this.jwGetPlaylist=function(){return[u]};this.jwGetPlaylistIndex=function(){return 0};this.jwGetStretching=function(){return n.config.stretching};this.jwAddEventListener=function(a,b){G.addEventListener(a,b)};this.jwRemoveEventListener=function(a,b){G.removeEventListener(a,b)};this.skin=f.skin;this.id=f.id+"_instream";J=new e.model({});G=new b.eventdispatcher;f.jwAddEventListener(b.JWPLAYER_RESIZE,q);f.jwAddEventListener(b.JWPLAYER_FULLSCREEN,
q);return this}})(jwplayer.html5);
(function(e){var f=e.utils,c=f.css,b=e.html5.logo=function(a,d){function j(a){f.exists(a)&&a.stopPropagation();s&&g.link&&(n.jwPause(),n.jwSetFullscreen(!1),window.open(g.link,g.linktarget))}var n=a,h=n.id+"_logo",g,t,k=b.defaults,s=!1;this.resize=function(){};this.element=function(){return t};this.offset=function(a){c("#"+h+" ",{"margin-bottom":a})};this.position=function(){return g.position};this.margin=function(){return parseInt(g.margin)};this.hide=function(a){if(g.hide||a)s=!1,t.style.visibility=
"hidden",t.style.opacity=0};this.show=function(){s=!0;t.style.visibility="visible";t.style.opacity=1};var l="o";n.edition&&(l=n.edition(),l="pro"==l?"p":"premium"==l?"r":"ads"==l?"a":"free"==l?"f":"o");k.link="http://www.longtailvideo.com/jwpabout/?a\x3dl\x26v\x3d"+e.version+"\x26m\x3dh\x26e\x3d"+l;g=f.extend({},k,d);g.hide="true"==g.hide.toString();t=document.createElement("img");t.className="jwlogo";t.id=h;if(g.file){var k=/(\w+)-(\w+)/.exec(g.position),l={},q=g.margin;3==k.length?(l[k[1]]=q,l[k[2]]=
q):l.top=l.right=q;c("#"+h+" ",l);t.src=(g.prefix?g.prefix:"")+g.file;t.onclick=j}else t.style.display="none";return this};b.defaults={prefix:f.repo(),file:"logo.png",link:"http://www.longtailvideo.com/jwpabout/?a\x3dl\x26v\x3d"+e.version+"\x26m\x3dh\x26e\x3df",linktarget:"_top",margin:8,hide:!1,position:"top-right"};c(".jwlogo",{cursor:"pointer",position:"absolute","z-index":100,opacity:0});f.transitionStyle(".jwlogo","visibility .15s, opacity .15s")})(jwplayer);
(function(e){var f=e.html5,c=e.utils,b=c.css,a=void 0;f.menu=function(d,e,n,h){function g(a,b){return function(){u(a);s&&s(b)}}function t(a,b){var c=document.createElement("div");a&&(c.className=a);b&&b.appendChild(c);return c}function k(b){return(b=n.getSkinElement("tooltip",b))?b:{width:0,height:0,src:a}}var s=h,l=new f.overlay(e+"_overlay",n);h=c.extend({fontcase:a,fontcolor:"#cccccc",fontsize:11,fontweight:a,activecolor:"#ffffff",overcolor:"#ffffff"},n.getComponentSettings("tooltip"));var q,y=
[];this.element=function(){return l.element()};this.addOption=function(a,b){var c=t("jwoption",q);c.id=e+"_option_"+b;c.innerHTML=a;c.addEventListener("click",g(y.length,b));y.push(c)};this.clearOptions=function(){for(;0<y.length;)q.removeChild(y.pop())};var u=this.setActive=function(a){for(var b=0;b<y.length;b++){var c=y[b];c.className=c.className.replace(" active","");b==a&&(c.className+=" active")}};this.show=l.show;this.hide=l.hide;this.offsetX=l.offsetX;q=t("jwmenu");q.id=e;var m=k("menuTop"+
d);d=k("menuOption");var A=k("menuOptionOver"),r=k("menuOptionActive");m&&q.appendChild(m.image);d&&(m="#"+e+" .jwoption",b(m,{"background-image":d.src,height:d.height,color:h.fontcolor,"padding-left":d.width,font:h.fontweight+" "+h.fontsize+"px Arial,Helvetica,sans-serif","line-height":d.height,"text-transform":"upper"==h.fontcase?"uppercase":a}),b(m+":hover",{"background-image":A.src?A.src:a,color:h.overcolor}),b(m+".active",{"background-image":r.src?r.src:a,color:h.activecolor}));l.setContents(q)};
b("."+"jwmenu jwoption".replace(/ /g," ."),{"background-repeat":"no-repeat",cursor:"pointer",position:"relative"})})(jwplayer);
(function(e){var f=jwplayer.utils,c=jwplayer.events;e.model=function(b){var a=this,d,j=f.getCookies(),n={controlbar:{},display:{}},h={autostart:!1,controls:!0,debug:void 0,fullscreen:!1,height:320,mobilecontrols:!1,mute:!1,playlist:[],playlistposition:"none",playlistsize:180,repeat:!1,skin:void 0,stretching:f.stretching.UNIFORM,width:480,volume:90},g={};g[c.JWPLAYER_MEDIA_MUTE]="mute";g[c.JWPLAYER_MEDIA_VOLUME]="volume";g[c.JWPLAYER_PLAYER_STATE]="newstate-\x3estate";g[c.JWPLAYER_MEDIA_BUFFER]="bufferPercent-\x3ebuffer";
g[c.JWPLAYER_MEDIA_TIME]="position,duration";a.getVideo=function(){return d};a.seekDrag=function(a){d.seekDrag(a)};a.setFullscreen=function(b){b!=a.fullscreen&&(a.fullscreen=b,a.sendEvent(c.JWPLAYER_FULLSCREEN,{fullscreen:b}))};a.setPlaylist=function(b){for(var d=[],e=0;e<b.length;e++){var g=f.extend({},b[e]);g.sources=f.filterSources(g.sources);0<g.sources.length&&d.push(g)}a.playlist=d;0==a.playlist.length?a.sendEvent(c.JWPLAYER_ERROR,{message:"Error loading playlist: No playable sources found"}):
(a.sendEvent(c.JWPLAYER_PLAYLIST_LOADED,{playlist:b}),a.item=-1,a.setItem(0))};a.setItem=function(b){b=b==a.playlist.length||-1>b?0:-1==b||b>a.playlist.length?a.playlist.length-1:b;b!=a.item&&(a.item=b,a.sendEvent(c.JWPLAYER_PLAYLIST_ITEM,{index:a.item}))};a.setVolume=function(b){a.mute&&0<b&&a.setMute(!1);b=Math.round(b);a.mute||f.saveCookie("volume",b);d.volume(b)};a.setMute=function(b){f.exists(b)||(b=!a.mute);f.saveCookie("mute",b);d.mute(b)};a.componentConfig=function(a){return n[a]};f.extend(a,
new c.eventdispatcher);var j=f.extend({},h,j,b),t;for(t in j)j[t]=f.serialize(j[t]);a.config=j;f.extend(a,{id:b.id,state:c.state.IDLE,duration:-1,position:0,buffer:0},a.config);a.playlist=[];a.setItem(0);b=document.createElement("video");d=new e.video(b);d.volume(a.volume);d.mute(a.mute);d.addGlobalListener(function(b){var c=g[b.type]?g[b.type].split(","):[],d,e;if(0<c.length){for(d=0;d<c.length;d++){var f=c[d].split("-\x3e"),h=f[0],f=f[1]?f[1]:h;a[f]!=b[h]&&(a[f]=b[h],e=!0)}e&&a.sendEvent(b.type,
b)}else a.sendEvent(b.type,b)})}})(jwplayer.html5);
(function(e){var f=e.utils,c=f.css,b=f.transitionStyle,a="top",d="bottom",j="right",n="left",h=void 0,g=document,t={fontcase:h,fontcolor:"#ffffff",fontsize:12,fontweight:h,activecolor:"#ffffff",overcolor:"#ffffff"};e.html5.overlay=function(b,e,l){function q(a){return"#"+w+(a?" ."+a:"")}function y(a,b){var c=g.createElement("div");a&&(c.className=a);b&&b.appendChild(c);return c}function u(a,b){var d;d=(d=r.getSkinElement("tooltip",a))?d:{width:0,height:0,src:"",image:h,ready:!1};var e=y(b,p);c(q(b.replace(" ",
".")),{"background-image":d.src});return[e,d]}function m(b,e){e||(e="");var f=u("cap"+b+e,"jwborder jw"+b+(e?e:"")),g=f[0],f=f[1],k={"background-image":f.src,width:b==n||e==n||b==j||e==j?f.width:h,height:b==a||e==a||b==d||e==d?f.height:h};k[b]=b==d&&!C||b==a&&C?D:0;e&&(k[e]=0);c(q(g.className.replace(/ /g,".")),k);g={};k={};f={left:f.width,right:f.width,top:(C?D:0)+f.height,bottom:(C?0:D)+f.height};e&&(g[e]=f[e],g[b]=0,k[b]=f[b],k[e]=0,c(q("jw"+b),g),c(q("jw"+e),k),G[b]=f[b],G[e]=f[e])}function A(){0!=
p.clientWidth&&(c(q(),{"margin-left":Math.round(v-p.clientWidth/2)}),c(q("jwarrow"),{"margin-left":Math.round(B.width/-2-v)}))}var r=e,w=b,p,x,v=0,B,D,C=l;b=f.extend({},t,r.getComponentSettings("tooltip"));var G={},z=this;z.element=function(){return p};var J;z.setContents=function(a){f.empty(x);x.appendChild(a);clearTimeout(J);J=setTimeout(A,0)};z.offsetX=function(a){v=a;clearTimeout(J);A()};z.borderWidth=function(){return G.left};z.show=function(){z.showing=!0;p.style.opacity=1;p.style.visibility=
"visible"};z.hide=function(){z.showing=!1;p.style.opacity=0;p.style.visibility="hidden"};p=y(".jwoverlay".replace(".",""));p.id=w;B=u("arrow","jwarrow")[1];D=B.height;c(q("jwarrow"),{position:"absolute",bottom:C?h:0,top:C?0:h,width:B.width,height:D,left:"50%"});m(a,n);m(d,n);m(a,j);m(d,j);m(n);m(j);m(a);m(d);u("background","jwback");c(q("jwback"),{left:G.left,right:G.right,top:G.top,bottom:G.bottom});x=y("jwcontents",p);c(q("jwcontents")+" *",{color:b.fontcolor,font:b.fontweight+" "+b.fontsize+"px Arial,Helvetica,sans-serif",
"text-transform":"upper"==b.fontcase?"uppercase":h});C&&f.transform(q("jwarrow"),"rotate(180deg)");c(q(),{padding:G.top+1+"px "+G.right+"px "+(G.bottom+1)+"px "+G.left+"px"});z.showing=!1};c(".jwoverlay",{position:"absolute",visibility:"hidden",opacity:0});c(".jwoverlay .jwcontents",{position:"relative","z-index":1});c(".jwoverlay .jwborder",{position:"absolute","background-size":"100% 100%"},!0);c(".jwoverlay .jwback",{position:"absolute","background-size":"100% 100%"});b(".jwoverlay","opacity .15s, visibility .15s, left .01s linear")})(jwplayer);
(function(e){var f=jwplayer.utils;e.player=function(c){function b(a){return function(){return d[a]}}var a=this,d,j,n,h;d=new e.model(c);a.id=d.id;j=new e.view(a,d);n=new e.controller(d,j);a._model=d;jwplayer.utils.css.block();a.jwPlay=n.play;a.jwPause=n.pause;a.jwStop=n.stop;a.jwSeek=n.seek;a.jwSetVolume=n.setVolume;a.jwSetMute=n.setMute;a.jwLoad=n.load;a.jwPlaylistNext=n.next;a.jwPlaylistPrev=n.prev;a.jwPlaylistItem=n.item;a.jwSetFullscreen=n.setFullscreen;a.jwResize=j.resize;a.jwSeekDrag=d.seekDrag;
a.jwSetStretching=n.setStretching;a.jwGetQualityLevels=n.getQualityLevels;a.jwGetCurrentQuality=n.getCurrentQuality;a.jwSetCurrentQuality=n.setCurrentQuality;a.jwGetCaptionsList=n.getCaptionsList;a.jwGetCurrentCaptions=n.getCurrentCaptions;a.jwSetCurrentCaptions=n.setCurrentCaptions;a.jwSetControls=j.setControls;a.jwGetSafeRegion=j.getSafeRegion;a.jwGetPlaylistIndex=b("item");a.jwGetPosition=b("position");a.jwGetDuration=b("duration");a.jwGetBuffer=b("buffer");a.jwGetWidth=b("width");a.jwGetHeight=
b("height");a.jwGetFullscreen=b("fullscreen");a.jwGetVolume=b("volume");a.jwGetMute=b("mute");a.jwGetState=b("state");a.jwGetStretching=b("stretching");a.jwGetPlaylist=b("playlist");a.jwGetControls=b("controls");a.jwDetachMedia=n.detachMedia;a.jwAttachMedia=n.attachMedia;a.jwLoadInstream=function(b,c){h||(h=new e.instream(a,d,j,n));setTimeout(function(){h.load(b,c)},10)};a.jwInstreamDestroy=function(){h&&h.jwInstreamDestroy()};a.jwPlayerDestroy=function(){j&&j.destroy()};a.jwAddEventListener=n.addEventListener;
a.jwRemoveEventListener=n.removeEventListener;a.jwDockAddButton=j.addButton;a.jwDockRemoveButton=j.removeButton;c=new e.setup(d,j,n);c.addEventListener(jwplayer.events.JWPLAYER_READY,function(a){n.playerReady(a);f.css.unblock()});c.addEventListener(jwplayer.events.JWPLAYER_ERROR,function(a){f.log("There was a problem setting up the player: ",a);f.css.unblock()});c.start()}})(jwplayer.html5);
(function(e){var f={size:180,backgroundcolor:"#333333",fontcolor:"#999999",overcolor:"#CCCCCC",activecolor:"#CCCCCC",titlecolor:"#CCCCCC",titleovercolor:"#FFFFFF",titleactivecolor:"#FFFFFF",fontweight:"normal",titleweight:"normal",fontsize:11,titlesize:13},c=jwplayer.events,b=jwplayer.utils,a=b.css,d=document;e.playlistcomponent=function(j,n){function h(a){return"#"+q.id+(a?" ."+a:"")}function g(a,b){var c=d.createElement(a);b&&(c.className=b);return c}function t(a){return function(){r=a;k.jwPlaylistItem(a);
k.jwPlay(!0)}}var k=j,s=k.skin,l=b.extend({},f,k.skin.getComponentSettings("playlist"),n),q,y,u,m,A=-1,r,w,p=60,x={background:void 0,divider:void 0,item:void 0,itemOver:void 0,itemImage:void 0,itemActive:void 0};this.element=function(){return q};this.redraw=function(){w&&w.redraw()};this.show=function(){b.show(q)};this.hide=function(){b.hide(q)};q=g("div","jwplaylist");q.id=k.id+"_jwplayer_playlistcomponent";y=g("div","jwlistcontainer");q.appendChild(y);for(var v in x)x[v]=s.getSkinElement("playlist",
v);x.item&&(p=x.item.height);var B=v=s=0;b.clearCss(h());a(h(),{"background-color":l.backgroundcolor});a(h("jwlist"),{"background-image":x.background?" url("+x.background.src+")":""});a(h("jwlist *"),{color:l.fontcolor,font:l.fontweight+" "+l.fontsize+"px Arial, Helvetica, sans-serif"});x.itemImage?(s=(p-x.itemImage.height)/2+"px ",v=x.itemImage.width,B=x.itemImage.height):(v=4*p/3,B=p);x.divider&&a(h("jwplaylistdivider"),{"background-image":"url("+x.divider.src+")","background-size":"100% "+x.divider.height+
"px",width:"100%",height:x.divider.height});a(h("jwplaylistimg"),{height:B,width:v,margin:s?s+s+s+s:"0 5px 0 0"});a(h("jwlist li"),{"background-image":x.item?"url("+x.item.src+")":"",height:p,"background-size":"100% "+p+"px",cursor:"pointer"});v={overflow:"hidden"};""!==l.activecolor&&(v.color=l.activecolor);x.itemActive&&(v["background-image"]="url("+x.itemActive.src+")");a(h("jwlist li.active"),v);a(h("jwlist li.active .jwtitle"),{color:l.titleactivecolor});v={overflow:"hidden"};""!==l.overcolor&&
(v.color=l.overcolor);x.itemOver&&(v["background-image"]="url("+x.itemOver.src+")");a(h("jwlist li:hover"),v);a(h("jwlist li:hover .jwtitle"),{color:l.titleovercolor});a(h("jwtextwrapper"),{height:p-5,position:"relative"});a(h("jwtitle"),{height:15,overflow:"hidden",display:"inline-block",width:"100%",color:l.titlecolor,"margin-top":s?s:7,"line-height":13,"font-size":l.titlesize,"font-weight":l.titleweight});a(h("jwdescription"),{display:"block","font-size":l.fontsize,"line-height":19,"margin-top":5,
overflow:"hidden",height:p,position:"relative"});k.jwAddEventListener(c.JWPLAYER_PLAYLIST_LOADED,function(){y.innerHTML="";for(var c=k.jwGetPlaylist(),d=[],f=0;f<c.length;f++)c[f]["ova.hidden"]||d.push(c[f]);if(u=d){c=g("ul","jwlist");c.id=q.id+"_ul"+Math.round(1E7*Math.random());m=c;for(c=0;c<u.length;c++){var h=c,d=u[h],f=g("li","jwitem"),j=void 0;f.id=m.id+"_item_"+h;0<h&&(j=g("div","jwplaylistdivider"),f.appendChild(j));h=g("div","jwplaylistimg jwfill");if(d.image||d["playlist.image"]||x.itemImage)j=
void 0,d["playlist.image"]?j=d["playlist.image"]:d.image?j=d.image:x.itemImage&&(j=x.itemImage.src),a("#"+f.id+" .jwplaylistimg",{"background-image":j?"url("+j+")":null}),f.appendChild(h);h=g("div","jwtextwrapper");j=g("span","jwtitle");j.innerHTML=d&&d.title?d.title:"";h.appendChild(j);d.description&&(j=g("span","jwdescription"),j.innerHTML=d.description,h.appendChild(j));f.appendChild(h);d=f;d.onclick=t(c);m.appendChild(d)}A=k.jwGetPlaylistIndex();b.isIOS()&&window.iScroll?(q.innerHTML="",q.appendChild(m),
m.style.height=p*u.length+"px",new iScroll(q.id)):(y.appendChild(m),w=new e.playlistslider(q.id+"_slider",k.skin,q,m))}});k.jwAddEventListener(c.JWPLAYER_PLAYLIST_ITEM,function(a){0<=A&&(d.getElementById(m.id+"_item_"+A).className="jwitem",A=a.index);d.getElementById(m.id+"_item_"+a.index).className="jwitem active";a=k.jwGetPlaylistIndex();a!=r&&(r=-1,b.isIOS()&&window.iScroll?m.scrollTop=a*p:w&&w.visible()&&w.thumbPosition(a/(k.jwGetPlaylist().length-1)))});return this};a(".jwplaylist",{position:"absolute",
width:"100%",height:"100%"});b.dragStyle(".jwplaylist","none");a(".jwplaylist .jwplaylistimg",{position:"relative",width:"100%","float":"left",margin:"0 5px 0 0",background:"#000",overflow:"hidden"});a(".jwplaylist .jwlist",{position:"absolute",width:"100%","list-style":"none",margin:0,padding:0});a(".jwplaylist .jwlistcontainer",{position:"absolute",overflow:"hidden",width:"100%",height:"100%"});a(".jwplaylist .jwlist li",{width:"100%"});a(".jwplaylist .jwtextwrapper",{overflow:"hidden"});a(".jwplaylist .jwplaylistdivider",
{position:"absolute"})})(jwplayer.html5);
(function(e){var f=jwplayer,c=f.utils,b=f.events;e.playlistloader=function(){function a(a){try{var d=a.responseXML.firstChild;"xml"==e.parsers.localName(d)&&(d=d.nextSibling);if("rss"!=e.parsers.localName(d))j("Not a valid RSS feed");else{var t=new f.playlist(e.parsers.rssparser.parse(d));if(a=t){var d=[],k,s,l;for(k=0;k<a.length;k++)if(s=a[k],(l=c.filterSources(s.sources))&&l.length)s.sources=l,d.push(s);t=d}else t=void 0;t&&t.length&&t[0].sources&&t[0].sources.length&&t[0].sources[0].file?n.sendEvent(b.JWPLAYER_PLAYLIST_LOADED,
{playlist:t}):j("No playable sources found")}}catch(q){j()}}function d(a){j(a.match(/invalid/i)?"Not a valid RSS feed":"")}function j(a){n.sendEvent(b.JWPLAYER_ERROR,{message:a?a:"Error loading file"})}var n=new b.eventdispatcher;c.extend(this,n);this.load=function(b){c.ajax(b,a,d)}}})(jwplayer.html5);
(function(e){function f(){var a=[],b;for(b=0;b<arguments.length;b++)a.push(".jwplaylist ."+arguments[b]);return a.join(",")}var c=jwplayer.utils,b=c.css,a=document,d=window,j=void 0;e.playlistslider=function(e,f,g,t){function k(a){return"#"+r.id+(a?" ."+a:"")}function s(c,d,e,f){var g=a.createElement("div");c&&(g.className=c,d&&b(k(c),{"background-image":d.src?d.src:j,"background-repeat":f?"repeat-y":"no-repeat",height:f?j:d.height}));e&&e.appendChild(g);return g}function l(a){return(a=A.getSkinElement("playlist",
a))?a:{width:0,height:0,src:j}}function q(a){if(C)return a=a?a:d.event,Y(v-(a.detail?-1*a.detail:a.wheelDelta/40)/10),a.stopPropagation&&a.stopPropagation(),a.preventDefault&&a.preventDefault(),a.cancelBubble=!0,a.cancel=!0,a.returnValue=!1}function y(a){if(x||"click"==a.type){var b=c.bounds(w),d=p.clientHeight/2;Y((a.pageY-b.top-d)/(b.height-d-d))}}function u(a){return function(b){0<b.button||(Y(v+0.05*a),B=setTimeout(function(){D=setInterval(function(){Y(v+0.05*a)},50)},500))}}function m(){x=!1;
d.removeEventListener("mousemove",y);d.removeEventListener("mouseup",m);a.onselectstart=j;clearTimeout(B);clearInterval(D)}var A=f,r,w,p,x,v=0,B,D,C=!0,G,z,J,M,H,K,R,X;this.element=function(){return r};this.visible=function(){return C};var N=this.redraw=function(){clearTimeout(X);X=setTimeout(function(){if(t&&t.clientHeight){var a=t.parentNode.clientHeight/t.clientHeight;0>a&&(a=0);1<a?C=!1:(C=!0,b(k("jwthumb"),{height:Math.max(w.clientHeight*a,M.height+H.height)}));b(k(),{visibility:C?"visible":
"hidden"});t&&(t.style.width=C?t.parentElement.clientWidth-J.width+"px":"")}else X=setTimeout(N,10)},0)},Y=this.thumbPosition=function(a){isNaN(a)&&(a=0);v=Math.max(0,Math.min(1,a));b(k("jwthumb"),{top:K+(w.clientHeight-p.clientHeight)*v});t&&(t.style.top=(r.clientHeight-t.scrollHeight)*v+"px")};r=s("jwslider",null,g);r.id=e;r.addEventListener("mousedown",function(b){0==b.button&&(x=!0);a.onselectstart=function(){return!1};d.addEventListener("mousemove",y,!1);d.addEventListener("mouseup",m,!1)},!1);
r.addEventListener("click",y,!1);G=l("sliderCapTop");z=l("sliderCapBottom");J=l("sliderRail");e=l("sliderRailCapTop");f=l("sliderRailCapBottom");g=l("sliderThumb");M=l("sliderThumbCapTop");H=l("sliderThumbCapBottom");K=G.height;R=z.height;b(k(),{width:J.width});b(k("jwrail"),{top:K,bottom:R});b(k("jwthumb"),{top:K});G=s("jwslidertop",G,r);z=s("jwsliderbottom",z,r);w=s("jwrail",null,r);p=s("jwthumb",null,r);G.addEventListener("mousedown",u(-1),!1);z.addEventListener("mousedown",u(1),!1);s("jwrailtop",
e,w);s("jwrailback",J,w,!0);s("jwrailbottom",f,w);b(k("jwrailback"),{top:e.height,bottom:f.height});s("jwthumbtop",M,p);s("jwthumbback",g,p,!0);s("jwthumbbottom",H,p);b(k("jwthumbback"),{top:M.height,bottom:H.height});N();t&&(t.addEventListener("mousewheel",q,!1),t.addEventListener("DOMMouseScroll",q,!1));return this};b(f("jwslider"),{position:"absolute",height:"100%",visibility:"hidden",right:0,top:0,cursor:"pointer","z-index":1});b(f("jwslider")+" *",{position:"absolute",width:"100%","background-position":"center",
"background-size":"100% 100%"});b(f("jwslidertop","jwrailtop","jwthumbtop"),{top:0});b(f("jwsliderbottom","jwrailbottom","jwthumbbottom"),{bottom:0})})(jwplayer.html5);
(function(e){var f=jwplayer.utils,c=f.css,b=document,a="none";e.rightclick=function(c,j){function n(a){var c=b.createElement("div");c.className=a.replace(".","");return c}function h(){k||(s.style.display=a)}var g,t=f.extend({aboutlink:"http://www.longtailvideo.com/jwpabout/?a\x3dr\x26v\x3d"+e.version+"\x26m\x3dh\x26e\x3do",abouttext:"About JW Player "+e.version+"..."},j),k=!1,s,l;this.element=function(){return s};this.destroy=function(){b.removeEventListener("mousedown",h,!1)};g=b.getElementById(c.id);
s=n(".jwclick");s.id=c.id+"_menu";s.style.display=a;g.oncontextmenu=function(b){if(!k){null==b&&(b=window.event);var c=f.bounds(g),d=c.top,c=c.left;s.style.display=a;s.style.left=b.pageX-c+"px";s.style.top=b.pageY-d+"px";s.style.display="block";b.preventDefault()}};s.onmouseover=function(){k=!0};s.onmouseout=function(){k=!1};b.addEventListener("mousedown",h,!1);l=n(".jwclick_item");l.innerHTML=t.abouttext;l.onclick=function(){window.location.href=t.aboutlink};s.appendChild(l);g.appendChild(s)};c(".jwclick",
{"background-color":"#FFF","-webkit-border-radius":5,"-moz-border-radius":5,"border-radius":5,height:"auto",border:"1px solid #bcbcbc","font-family":'"MS Sans Serif", "Geneva", sans-serif',"font-size":10,width:320,"-webkit-box-shadow":"5px 5px 7px rgba(0,0,0,.10), 0px 1px 0px rgba(255,255,255,.3) inset","-moz-box-shadow":"5px 5px 7px rgba(0,0,0,.10), 0px 1px 0px rgba(255,255,255,.3) inset","box-shadow":"5px 5px 7px rgba(0,0,0,.10), 0px 1px 0px rgba(255,255,255,.3) inset",position:"absolute","z-index":999},
!0);c(".jwclick div",{padding:"8px 21px",margin:"0px","background-color":"#FFF",border:"none","font-family":'"MS Sans Serif", "Geneva", sans-serif',"font-size":10,color:"inherit"},!0);c(".jwclick_item",{padding:"8px 21px","text-align":"left",cursor:"pointer"},!0);c(".jwclick_item:hover",{"background-color":"#595959",color:"#FFF"},!0);c(".jwclick_item a",{"text-decoration":a,color:"#000"},!0);c(".jwclick hr",{width:"100%",padding:0,margin:0,border:"1px #e9e9e9 solid"},!0)})(jwplayer.html5);
(function(e){var f=jwplayer,c=f.utils,b=f.events,a=f.playlist,d=2,j=3,n=4;e.setup=function(f,g){function t(a,b,c){D.push({name:a,method:b,depends:c})}function k(){for(var a=0;a<D.length;a++){var b=D[a],c;a:{if(c=b.depends){c=c.toString().split(",");for(var d=0;d<c.length;d++)if(!p[c[d]]){c=!1;break a}}c=!0}if(c){D.splice(a,1);try{b.method(),k()}catch(e){A(e.message)}return}}0<D.length&&!B&&setTimeout(k,500)}function s(){p[d]=!0}function l(a){A("Error loading skin: "+a)}function q(a){y(a.playlist)}
function y(a){r.setPlaylist(a);0==r.playlist[0].sources.length?A("Error loading playlist: No playable sources found"):p[j]=!0}function u(a){A("Error loading playlist: "+a.message)}function m(){p[n]=!0}function A(a){B=!0;v.sendEvent(b.JWPLAYER_ERROR,{message:a});w.setupError(a)}var r=f,w=g,p={},x,v=new b.eventdispatcher,B=!1,D=[];c.extend(this,v);this.start=k;t(1,function(){p[1]=!0});t(d,function(){x=new e.skin;x.load(r.config.skin,s,l)},1);t(j,function(){switch(c.typeOf(r.config.playlist)){case "string":var d=
new e.playlistloader;d.addEventListener(b.JWPLAYER_PLAYLIST_LOADED,q);d.addEventListener(b.JWPLAYER_ERROR,u);d.load(r.config.playlist);break;case "array":y(new a(r.config.playlist))}},1);t(n,function(){var a=r.playlist[r.item].image;if(a){var b=new Image;b.addEventListener("load",m,!1);b.addEventListener("error",m,!1);b.src=a;setTimeout(m,500)}else p[n]=!0},j);t(5,function(){w.setup(x);p[5]=!0},n+","+d);t(6,function(){p[6]=!0},"5,"+j);t(7,function(){v.sendEvent(b.JWPLAYER_READY);p[7]=!0},6)}})(jwplayer.html5);
(function(e){e.skin=function(){var f={},c=!1;this.load=function(b,a,d){new e.skinloader(b,function(b){c=!0;f=b;"function"==typeof a&&a()},function(a){"function"==typeof d&&d(a)})};this.getSkinElement=function(b,a){b=b.toLowerCase();a=a.toLowerCase();if(c)try{return f[b].elements[a]}catch(d){jwplayer.utils.log("No such skin component / element: ",[b,a])}return null};this.getComponentSettings=function(b){b=b.toLowerCase();return c&&f&&f[b]?f[b].settings:null};this.getComponentLayout=function(b){b=b.toLowerCase();
if(c){var a=f[b].layout;if(a&&(a.left||a.right||a.center))return f[b].layout}return null}}})(jwplayer.html5);
(function(e){var f=jwplayer.utils,c="Skin formatting error";e.skinloader=function(b,a,d){function j(a){s=a;f.ajax(f.getAbsolutePath(m),function(a){try{f.exists(a.responseXML)&&h(a.responseXML)}catch(b){q(c)}},function(a){q(a)})}function n(a,b){return a?a.getElementsByTagName(b):null}function h(a){var b=n(a,"skin")[0];a=n(b,"component");b=b.getAttribute("target");(!b||parseFloat(b)>parseFloat(jwplayer.version))&&q("Incompatible player version");if(0===a.length)l(s);else for(b=0;b<a.length;b++){var c=
k(a[b].getAttribute("name")),d={settings:{},elements:{},layout:{}},e=n(n(a[b],"elements")[0],"element");s[c]=d;for(var h=0;h<e.length;h++)t(e[h],c);if((c=n(a[b],"settings")[0])&&0<c.childNodes.length){c=n(c,"setting");for(e=0;e<c.length;e++){var h=c[e].getAttribute("name"),j=c[e].getAttribute("value");/color$/.test(h)&&(j=f.stringToColor(j));d.settings[k(h)]=j}}if((c=n(a[b],"layout")[0])&&0<c.childNodes.length){c=n(c,"group");for(e=0;e<c.length;e++){j=c[e];h={elements:[]};d.layout[k(j.getAttribute("position"))]=
h;for(var m=0;m<j.attributes.length;m++){var u=j.attributes[m];h[u.name]=u.value}j=n(j,"*");for(m=0;m<j.length;m++){u=j[m];h.elements.push({type:u.tagName});for(var z=0;z<u.attributes.length;z++){var A=u.attributes[z];h.elements[m][k(A.name)]=A.value}f.exists(h.elements[m].name)||(h.elements[m].name=u.tagName)}}}y=!1;g()}}function g(){clearInterval(u);A||(u=setInterval(function(){a:{for(var a in s)if("properties"!=a)for(var b in s[a].elements)if(!(s[k(a)]?s[k(a)].elements[k(b)]:null).ready)break a;
!1==y&&(clearInterval(u),l(s))}},100))}function t(a,b){b=k(b);var c=new Image,d=k(a.getAttribute("name")),e=a.getAttribute("src");if(0!==e.indexOf("data:image/png;base64,"))var h=f.getAbsolutePath(m),e=[h.substr(0,h.lastIndexOf("/")),b,e].join("/");s[b].elements[d]={height:0,width:0,src:"",ready:!1,image:c};c.onload=function(){var a=b,e=s[k(a)]?s[k(a)].elements[k(d)]:null;e?(e.height=c.height,e.width=c.width,e.src=c.src,e.ready=!0,g()):f.log("Loaded an image for a missing element: "+a+"."+d)};c.onerror=
function(){A=!0;g();q("Skin image not found: "+this.src)};c.src=e}function k(a){return a?a.toLowerCase():""}var s={},l=a,q=d,y=!0,u,m=b,A=!1;"string"!=typeof m||""===m?h(e.defaultskin().xml):"xml"!=f.extension(m)?q("Skin not a valid file type"):new e.skinloader("",j,q)}})(jwplayer.html5);
(function(e){var f=e.utils,c=e.events,b=c.state;e.html5.video=function(a){function d(a,b){H&&M.sendEvent(a,b)}function e(){}function n(){H&&(C==b.PLAYING&&!D)&&(p=Number(r.currentTime.toFixed(1)),d(c.JWPLAYER_MEDIA_TIME,{position:p,duration:w}))}function h(a){H&&(x||(x=!0,v||(v=!0,d(c.JWPLAYER_MEDIA_BUFFER_FULL))),"loadedmetadata"==a.type&&(r.muted&&(r.muted=!1,r.muted=!0),d(c.JWPLAYER_MEDIA_META,{duration:r.duration,height:r.videoHeight,width:r.videoWidth})))}function g(a){H&&!D&&(r.paused?r.currentTime==
r.duration&&3<r.duration?y():W():(!f.isFF()||!("play"==a.type&&C==b.BUFFERING))&&l(b.PLAYING))}function t(a){var b;if("array"==f.typeOf(a)&&0<a.length){b=[];for(var c=0;c<a.length;c++){var d=a[c],e={};e.label=k(d)?k(d):c;d.width&&(e.width=d.width);d.height&&(e.height=d.height);d.bitrate&&(e.bitrate=d.bitrate);b[c]=e}}return b}function k(a){return a.label?a.label:a.height?a.height+"p":a.width?Math.round(9*a.width/16)+"p":a.bitrate?a.bitrate+"kbps":0}function s(){v=x=!1;A=K[R];l(b.BUFFERING);r.src=
A.file;r.load();z=setInterval(q,100);if((f.isIPod()||f.isAndroid(2.3))&&!v)v=!0,d(c.JWPLAYER_MEDIA_BUFFER_FULL)}function l(a){if(!(a==b.PAUSED&&C==b.IDLE)&&!D&&C!=a){var e=C;C=a;d(c.JWPLAYER_PLAYER_STATE,{oldstate:e,newstate:a})}}function q(){if(H){var a;a=0==r.buffered.length||0==r.duration?0:r.buffered.end(r.buffered.length-1)/r.duration;a!=J&&(J=a,d(c.JWPLAYER_MEDIA_BUFFER,{bufferPercent:Math.round(100*J)}));1<=a&&clearInterval(z)}}function y(){C!=b.IDLE&&(R=-1,d(c.JWPLAYER_MEDIA_BEFORECOMPLETE),
Y=!0,H&&(l(b.IDLE),d(c.JWPLAYER_MEDIA_COMPLETE),Y=!1))}var u={abort:e,canplay:h,canplaythrough:e,durationchange:function(){if(H){var a=Number(r.duration.toFixed(1));w!=a&&(w=a);X&&(0<B&&a>B)&&ha(B);n()}},emptied:e,ended:function(){y()},error:function(){H&&(f.log("Error playing media: %o",r.error),M.sendEvent(c.JWPLAYER_MEDIA_ERROR,{message:"Error loading media: File could not be played"}),l(b.IDLE))},loadeddata:e,loadedmetadata:h,loadstart:e,pause:g,play:g,playing:g,progress:function(){x&&(0<B&&!X)&&
setTimeout(function(){ha(B)},200)},ratechange:e,readystatechange:e,seeked:function(){D||d(c.JWPLAYER_MEDIA_SEEK,{position:p,offset:r.currentTime})},seeking:e,stalled:e,suspend:e,timeupdate:n,volumechange:function(){d(c.JWPLAYER_MEDIA_VOLUME,{volume:Math.round(100*r.volume)});d(c.JWPLAYER_MEDIA_MUTE,{mute:r.muted})},waiting:function(){H&&l(b.BUFFERING)}},m,A,r,w,p,x,v,B,D,C=b.IDLE,G,z=-1,J=-1,M=new c.eventdispatcher,H=!1,K,R=-1,X=f.isAndroid(),N=this,Y=!1;f.extend(N,M);N.load=function(a){if(H){m=a;
B=0;w=a.duration?a.duration:-1;p=0;K=m.sources;0>R&&(R=0);a=K.slice(0).sort(function(a,b){return Number(b.width)-Number(a.width)});var b=f.bounds(r),d,e;for(d=0;d<a.length;d++)if(e=a[d],e.width&&e.width<=b.width){R=K.indexOf(e);break}(a=t(K))&&M.sendEvent(c.JWPLAYER_MEDIA_LEVELS,{levels:a,currentQuality:R});s()}};N.stop=function(){H&&(r.removeAttribute("src"),f.isIE()||r.load(),R=-1,clearInterval(z),l(b.IDLE))};N.play=function(){H&&!D&&r.play()};var W=N.pause=function(){H&&(r.pause(),l(b.PAUSED))};
N.seekDrag=function(a){H&&((D=a)?r.pause():r.play())};var ha=N.seek=function(a){H&&(x?(B=0,r.currentTime=a):B=a)},Ha=N.volume=function(a){r.volume=Math.min(Math.max(0,a/100),1)};N.mute=function(a){f.exists(a)||(a=!r.mute);a?r.muted||(G=100*r.volume,r.muted=!0):r.muted&&(Ha(G),r.muted=!1)};N.detachMedia=function(){H=!1;return r};N.attachMedia=function(){H=!0;Y&&(l(b.IDLE),d(c.JWPLAYER_MEDIA_COMPLETE),Y=!1)};N.getTag=function(){return r};N.audioMode=function(){if(!K)return!1;var a=K[0].type;return"aac"==
a||"mp3"==a||"vorbis"==a};N.setCurrentQuality=function(a){R!=a&&(a=parseInt(a),0<=a&&(K&&K.length>a)&&(R=a,d(c.JWPLAYER_MEDIA_LEVEL_CHANGED,{currentQuality:a,levels:t(K)}),a=r.currentTime,s(),N.seek(a)))};N.getCurrentQuality=function(){return R};N.getQualityLevels=function(){return t(K)};r=a;for(var Ba in u)r.addEventListener(Ba,u[Ba],!1);r.controls=!0;r.controls=!1;H=!0}})(jwplayer);
(function(e){var f=jwplayer.utils,c=jwplayer.events,b=c.state,a=f.css,d=f.isMobile(),j=f.isIPad(),n=f.isIPod(),h=f.isAndroid(),g=document,t="jwmain",k="jwvideo",s="jwplaylistcontainer",l=!0,q=!1,y="hidden",u="none",m="block";e.view=function(A,r){function w(a){a&&(a.element().addEventListener("mousemove",v,q),a.element().addEventListener("mouseout",B,q))}function p(a,b){var c=g.createElement(a);b&&(c.className=b);return c}function x(){clearTimeout(qa);if(P.jwGetState()==b.PLAYING||P.jwGetState()==
b.PAUSED)W(),ta||(qa=setTimeout(D,Oa))}function v(){clearTimeout(qa);ta=l}function B(){ta=q}function D(){P.jwGetState()!=b.BUFFERING&&(Q&&(!S&&!E)&&Q.hide(),F&&(!T&&!E)&&F.hide(),X());clearTimeout(qa);qa=0}function C(a){ba.sendEvent(a.type,a)}function G(b,d){f.exists(b)&&f.exists(d)&&(L.width=b,L.height=d);U.style.width=isNaN(b)?b:b+"px";U.style.height=isNaN(d)?d:d+"px";I&&I.redraw();Q&&Q.redraw();O&&setTimeout(function(){O.offset(Q&&0<=O.position().indexOf("bottom")?Q.element().clientHeight+Q.margin():
0);F&&F.offset("top-left"==O.position()?O.element().clientWidth+O.margin():0)},500);var e=L.playlistsize,g=L.playlistposition;if(Z&&e&&("right"==g||"bottom"==g)){Z.redraw();var h={display:m},j={};h[g]=0;j[g]=e;"right"==g?h.width=e:h.height=e;a(Aa(s),h);a(Aa(t),j)}z(d);J();ba.sendEvent(c.JWPLAYER_RESIZE)}function z(a){S=(!d||E)&&40>=a&&0>a.toString().indexOf("%");Q&&(S?(Q.audioMode(l),W(),I.hidePreview(l),Y(),ha(q)):(Q.audioMode(q),Ia(P.jwGetState())));O&&S&&X();U.style.backgroundColor=S?"transparent":
"#000"}function J(){V&&f.stretch(L.stretching,V,ka.clientWidth,ka.clientHeight,V.videoWidth,V.videoHeight)}function M(a){if(L.fullscreen)switch(a.keyCode){case 27:ya(q)}}function H(a){a?(U.className+=" jwfullscreen",g.getElementsByTagName("body")[0].style["overflow-y"]=y):(U.className=U.className.replace(/\s+jwfullscreen/,""),g.getElementsByTagName("body")[0].style["overflow-y"]="")}function K(){var a;a:{a=[g.mozFullScreenElement,g.webkitCurrentFullScreenElement,V.webkitDisplayingFullscreen];for(var b=
0;b<a.length;b++)if(a[b]&&(!a[b].id||a[b].id==P.id)){a=l;break a}a=q}L.fullscreen!=a&&ya(a)}function R(){F&&(!S&&(!d||T))&&F.show()}function X(){O&&(!E||S)&&O.hide(S)}function N(){I&&L.controls&&!S&&(!n||P.jwGetState()==b.IDLE)&&I.show();if(d&&!E&&(h&&(ca.style.display=m),!d||!L.fullscreen))V.controls=!1}function Y(){I&&(d&&!E&&(h&&(ca.style.display=u),V.controls=!0),I.hide())}function W(){if(L.controls||S)Q&&Q.show(),R();O&&!S&&O.show()}function ha(b){b=b&&!S;a(Aa(k),{visibility:b?"visible":y,opacity:b?
1:0})}function Ha(){T=l;ya(!1);L.controls&&R()}function Ba(){}function ia(a){T=q;clearTimeout(Ea);Ea=setTimeout(function(){Ia(a.newstate)},100)}function Ia(a){switch(a){case b.PLAYING:!L.getVideo().audioMode()||d?(ha(l),J(),I.hidePreview(l),d&&(!j||!E)&&Y()):(ha(q),I.hidePreview(S));x();break;case b.IDLE:ha(q);D();S||(I.hidePreview(q),N(),la.hide||O&&!S&&O.show());break;case b.BUFFERING:N();d?ha(l):W();break;case b.PAUSED:N(),(!d||E)&&W()}}function Aa(a){return"#"+P.id+(a?" ."+a:"")}var P=A,L=r,U,
pa,ca,sa,qa=0,Oa=2E3,V,ka,ua,Q,I,F,O,la=f.extend({},L.componentConfig("logo")),ga,Z,S,E=L.mobilecontrols,za=q,T,$,na,ta=q,ba=new c.eventdispatcher;f.extend(this,ba);this.getCurrentCaptions=function(){return ga.getCurrentCaptions()};this.setCurrentCaptions=function(a){ga.setCurrentCaptions(a)};this.getCaptionsList=function(){return ga.getCaptionsList()};this.setup=function(a){if(!za){P.skin=a;pa=p("span",t);ka=p("span",k);V=L.getVideo().getTag();ka.appendChild(V);ca=p("span","jwcontrols");ua=p("span",
"jwinstream");sa=p("span",s);a=L.height;var h=L.componentConfig("controlbar"),j=L.componentConfig("display");z(a);ga=new e.captions(P,L.captions);ga.addEventListener(c.JWPLAYER_CAPTIONS_LIST,C);ga.addEventListener(c.JWPLAYER_CAPTIONS_CHANGED,C);ca.appendChild(ga.element());I=new e.display(P,j);I.addEventListener(c.JWPLAYER_DISPLAY_CLICK,C);S&&I.hidePreview(l);ca.appendChild(I.element());O=new e.logo(P,la);ca.appendChild(O.element());F=new e.dock(P,L.componentConfig("dock"));ca.appendChild(F.element());
$=P.edition?new e.rightclick(P,{abouttext:L.abouttext,aboutlink:L.aboutlink}):new e.rightclick(P,{});L.playlistsize&&(L.playlistposition&&L.playlistposition!=u)&&(Z=new e.playlistcomponent(P,{}),sa.appendChild(Z.element()));if(!d||E)Q=new e.controlbar(P,h),ca.appendChild(Q.element()),E&&W();setTimeout(function(){G(L.width,L.height)},0);pa.appendChild(ka);pa.appendChild(ca);pa.appendChild(ua);a=p("div");a.style.position="absolute";a.style.width="100%";a.style.height="100%";a.appendChild(pa);a.appendChild(sa);
U.appendChild(a);g.addEventListener("webkitfullscreenchange",K,q);V.addEventListener("webkitbeginfullscreen",K,q);V.addEventListener("webkitendfullscreen",K,q);g.addEventListener("mozfullscreenchange",K,q);g.addEventListener("keydown",M,q);P.jwAddEventListener(c.JWPLAYER_PLAYER_READY,Ba);P.jwAddEventListener(c.JWPLAYER_PLAYER_STATE,ia);P.jwAddEventListener(c.JWPLAYER_PLAYLIST_COMPLETE,Ha);ia({newstate:b.IDLE});ca.addEventListener("mouseout",D,q);ca.addEventListener("mousemove",x,q);f.isIE()&&(ka.addEventListener("mousemove",
x,q),ka.addEventListener("click",I.clickHandler));w(Q);w(F);w(O)}};var ya=this.fullscreen=function(a){f.exists(a)||(a=!L.fullscreen);a?L.fullscreen||(j||H(l),U.requestFullScreen?U.requestFullScreen():U.mozRequestFullScreen?U.mozRequestFullScreen():U.webkitRequestFullScreen&&U.webkitRequestFullScreen(),L.setFullscreen(l)):(j||H(q),L.fullscreen&&(L.setFullscreen(q),g.cancelFullScreen?g.cancelFullScreen():g.mozCancelFullScreen?g.mozCancelFullScreen():g.webkitCancelFullScreen?g.webkitCancelFullScreen():
V.webkitExitFullScreen&&V.webkitExitFullScreen()),j&&P.jwGetState()==b.PAUSED&&setTimeout(N,500));Q&&Q.redraw();I&&I.redraw();F&&F.redraw();J();L.fullscreen?na=setInterval(J,200):clearInterval(na);setTimeout(function(){var a=f.bounds(pa);L.width=a.width;L.height=a.height;ba.sendEvent(c.JWPLAYER_RESIZE)},0)};this.resize=G;this.resizeMedia=J;var fa=this.completeSetup=function(){a(Aa(),{opacity:1})},Ea;this.setupInstream=function(){};this.destroyInstream=function(){};this.setupError=function(a){za=!0;
jwplayer.embed.errorScreen(U,a);fa()};this.addButton=function(a,b,c,d){F&&F.addButton(a,b,c,d)};this.removeButton=function(a){F&&F.removeButton(a)};this.setControls=function(a){var b=L.controls;a=a?l:q;L.controls=a;a!=b&&(a?N():(Q&&(!S&&!E)&&Q.hide(),F&&(!T&&!E)&&F.hide(),X(),Y()),ba.sendEvent(c.JWPLAYER_CONTROLS,{controls:a}))};this.getSafeRegion=function(){var a=L.controls,b=f.bounds(pa),c=b.top,d=f.bounds(Q?Q.element():null),e=0<F.numButtons(),g=f.bounds(F.element()),h=f.bounds(O.element()),j=
0==O.position().indexOf("top"),e=Math.max(e?g.top+g.height-c:0,j?h.top+h.height-c:0),g=b.width,b=d.height?(j?d.top:h.top)-e-c:b.height-e;return{x:0,y:a?e:0,width:a?g:0,height:a?b:0}};this.destroy=function(){g.removeEventListener("webkitfullscreenchange",K,q);g.removeEventListener("mozfullscreenchange",K,q);V.removeEventListener("webkitbeginfullscreen",K,q);V.removeEventListener("webkitendfullscreen",K,q);g.removeEventListener("keydown",M,q);$&&$.destroy()};U=p("div","jwplayer");U.id=P.id;G(L.width,
L.height);var xa=document.getElementById(P.id);xa.parentNode.replaceChild(U,xa)};a(".jwplayer",{position:"relative",opacity:0,"min-height":f.isMobile()?200:0,"-webkit-transition":"opacity .5s ease","-moz-transition":"opacity .5s ease","-o-transition":"opacity .5s ease"});a("."+t,{position:"absolute",left:0,right:0,top:0,bottom:0,"-webkit-transition":"opacity .5s ease","-moz-transition":"opacity .5s ease","-o-transition":"opacity .5s ease"});a("."+k+" ,.jwcontrols",{position:"absolute",height:"100%",
width:"100%","-webkit-transition":"opacity .5s ease","-moz-transition":"opacity .5s ease","-o-transition":"opacity .5s ease"});a("."+k,{overflow:y,visibility:y,opacity:0,cursor:"pointer"});a("."+k+" video",{background:"transparent",width:"100%",height:"100%"});a("."+s,{position:"absolute",height:"100%",width:"100%",display:u});a(".jwinstream",{position:"absolute",top:0,left:0,bottom:0,right:0,display:"none"});a(".jwplayer.jwfullscreen",{width:"100%",height:"100%",left:0,right:0,top:0,bottom:0,"z-index":1E3,
position:"fixed"},l);a(".jwplayer.jwfullscreen ."+t,{left:0,right:0,top:0,bottom:0},l);a(".jwplayer.jwfullscreen ."+s,{display:u},l);a(".jwplayer .jwuniform",{"background-size":"contain !important"});a(".jwplayer .jwfill",{"background-size":"cover !important","background-position":"center"});a(".jwplayer .jwexactfit",{"background-size":"100% 100% !important"})})(jwplayer.html5);
(function(e){var f=jwplayer.utils.extend,c=e.logo,b;b=function(a,b){"free"==a.edition()?b=null:(c.defaults.file="",c.defaults.prefix="");f(this,new c(a,b))};b.defaults={prefix:"",file:"data:image/png;base64, %3D%3D"};
f(b.defaults,c.defaults);e.logo=b})(jwplayer.html5);(function(e){var f=e.model;e.model=function(c){var b=new jwplayer.utils.key(c.key),a=new f(c),d=a.componentConfig;a.edition=function(){return b.edition()};a.componentConfig=function(b){return"logo"==b?a.logo:d(b)};return a}})(jwplayer.html5);(function(e){e.player.prototype.edition=function(){return this._model.edition()}})(jwplayer.html5);
(function(e){var f=jwplayer.utils.extend,c=e.rightclick;e.rightclick=function(b,a){if("free"==b.edition())a.aboutlink="http://www.longtailvideo.com/jwpabout/?a\x3dr\x26v\x3d"+e.version+"\x26m\x3dh\x26e\x3df",delete a.abouttext;else{if(!a.aboutlink){var d="http://www.longtailvideo.com/jwpabout/?a\x3dr\x26v\x3d"+e.version+"\x26m\x3dh\x26e\x3d",j=b.edition();a.aboutlink=d+("pro"==j?"p":"premium"==j?"r":"ads"==j?"a":"f")}a.abouttext?a.abouttext="About "+a.abouttext+" ...":(d=b.edition(),d=d.charAt(0).toUpperCase()+
d.substr(1),a.abouttext="About JW Player "+e.version+" ("+d+" edition)")}f(this,new c(b,a))}})(jwplayer.html5);(function(e){var f=e.view;e.view=function(c,b){var a=new f(c,b);"invalid"==b.edition()&&a.setupError("Error setting up player: Invalid license key");return a}})(jwplayer.html5);